@@ -15,8 +15,8 @@ plot(t, y1, 'r-', t, y2, 'b-', t3, y3, 'bo',
      title='Simple Plot Demo',
      axis=(0, 3, -0.05, 0.6),
      xlabel='t', ylabel='y',
-     hardcopy='tmp1.eps',
+     savefig='tmp1.eps',
      show=True)
 
-hardcopy('tmp0.png') # this one can be included in HTML
+savefig('tmp0.png') # this one can be included in HTML
 raw_input('Press Return key to quit: ')
