@@ -13,6 +13,6 @@ y2 = f2(t)
 plot(t, y1, t, y2, xlabel='t', ylabel='y',
      legend=('t^2*exp(-t^2)', 't^4*exp(-t^2)'),
      title='Plotting two curves in the same plot',
-     hardcopy='tmp2.eps')
+     savefig='tmp2.eps')
 
 raw_input('Press Return key to quit: ')
