@@ -14,6 +14,6 @@ plot(t, y1, 'r-', t, y2, 'bo',
      xlabel='t', ylabel='y',
      legend=('t^2*exp(-t^2)', 't^4*exp(-t^2)'),
      title='Plotting two curves in the same plot',
-     hardcopy='tmp2.eps')
+     savefig='tmp2.eps')
 
 raw_input('Press Return key to quit: ')
