@@ -50,6 +50,16 @@ import time
 # Update Gnuplot.GnuplotOpts according to scitools.cfg
 _update_from_config_file(Gnuplot.GnuplotOpts.__dict__, section='gnuplot')
 
+def _check_terminal(term):
+    """Return True if the given terminal work with Gnuplot, otherwise False."""
+    f = open(tempfile.mktemp(suffix='.gnuplot'), 'w')
+    f.write('set term %s\n' % term)
+    f.close()
+    cmd = '%s < %s' % (Gnuplot.GnuplotOpts.gnuplot_command, f.name)
+    failure, output = system(cmd, verbose=False, failure_handling='silent')
+    os.remove(f.name)
+    return not failure
+
 def _check_terminals(terms):
     """Check if the default terminal (Gnuplot.GnuplotOpts.default_term)
     work with Gnuplot. If not, try any of the terminals given in terms.
@@ -62,13 +72,8 @@ def _check_terminals(terms):
     if len(terms) == 0 or default_term != terms[0]:
         terms = [default_term] + terms
     for term in terms:
-        test_term = open(tempfile.mktemp(suffix='.gnuplot'), 'w')
-        test_term.write('set term %s\n' % term)
-        test_term.close()
-        cmd = '%s < %s' % (Gnuplot.GnuplotOpts.gnuplot_command, test_term.name)
-        failure, output = system(cmd, verbose=False, failure_handling='silent')
-        os.remove(test_term.name)
-        if not failure:
+        term_ok = _check_terminal(term)
+        if term_ok:
             working_term = term
             break
     if working_term is not None:
@@ -87,14 +92,14 @@ def _check_terminals(terms):
               Gnuplot.GnuplotOpts.gnuplot_command
 
 if sys.platform == "darwin":
-    _check_terminals(['aqua', 'x11'])
+    _check_terminals(['aqua', 'wxt', 'x11'])
 
 _gnuplotpy_major = Gnuplot.__version__[0]
 _gnuplotpy_minor = Gnuplot.__version__[2]
 if _gnuplotpy_major == 1 and _gnuplotpy_minor <= 7:
     if os.uname()[-1] == 'x86_64':
         # Gnuplot.py <= 1.7 only supports Numeric (not NumPy) and Numeric
-        # does not work on 64 bits platform. 
+        # does not work on 64 bits platform.
         print ("Warning: Gnuplot.py version %s is not support on 64 bits " \
                "platform. Please upgrade to Gnuplot.py 1.8 or newer.") % \
                Gnuplot.__version__
@@ -187,15 +192,15 @@ class GnuplotBackend(BaseClass):
     def __init__(self):
         BaseClass.__init__(self)
         self._init()
-        
+
     def _init(self, *args, **kwargs):
         """Perform initialization that is special for this backend."""
-        
+
         # Necessary to add a Gnuplot Session as _g to the Figure instance.
         # self._g will now point to the correct instance saved as _g in
         # curfig.
         self.figure(self.getp('curfig'))
-        
+
         # conversion tables for format strings:
         self._markers = {
             '': None,# no marker
@@ -213,7 +218,7 @@ class GnuplotBackend(BaseClass):
             'p': 5,  # pentagram --> square
             'h': 5,  # hexagram --> square
             }
-         
+
         self._colors = {
             '' : 1,  # no color --> red (gives solid line)
             'r': 1,  # red
@@ -225,7 +230,7 @@ class GnuplotBackend(BaseClass):
             'k': -1, # black
             'w': 7,  # white --> orange
             }
-        
+
         self._line_styles = {
             '': None,       # no line --> point
             '-': 'lines',   # solid line
@@ -246,6 +251,8 @@ class GnuplotBackend(BaseClass):
             'WestOutside': ('vertical',.01,.21,.03,.6)
             }
 
+        self._doing_PS = False  # indicator for PostScript hardcopy
+
         if DEBUG:
             print "Setting backend standard variables"
             for disp in 'self._markers self._colors self._line_styles'.split():
@@ -298,17 +305,17 @@ class GnuplotBackend(BaseClass):
             self._g('set zlabel "%s"' % zlabel)
         else:
             self._g('unset zlabel')
-        
+
     def _set_title(self, ax):
         """Add a title at the top of the axis."""
         if DEBUG:
             print "Setting title"
-        title = ax.getp('title')
+        title = self._fix_latex(ax.getp('title'))
         if title:
             self._g('set title "%s"' % title)
         else:
             self._g('unset title')
-    
+
     def _set_limits(self, ax):
         """Set axis limits in x, y, and z direction."""
         if DEBUG:
@@ -385,11 +392,21 @@ class GnuplotBackend(BaseClass):
             # In Gnuplot we cannot set individual aspects for the different
             # axes. Therefore we use dar[0] as the aspect ratio:
             self._g('set size ratio %s' % dar[0])
+        elif ax.getp('daspectmode') == 'equal':
+            xmin = ax.getp('xmin')
+            xmax = ax.getp('xmax')
+            ymin = ax.getp('ymin')
+            ymax = ax.getp('ymax')
+            try:
+                r = (ymax-ymin)/float(xmax-xmin)
+            except TypeError:
+                raise ValueError('daspectmode="equal" requires the axes to be explicitly set')
+            self._g('set size ratio %g' % r)
         else:
             # daspectmode is 'auto'. Plotting package handles data
             # aspect ratio automatically.
             pass
-        
+
     def _set_axis_method(self, ax):
         method = ax.getp('method')
         if method == 'equal':
@@ -415,7 +432,7 @@ class GnuplotBackend(BaseClass):
         Use either the default Cartesian coordinate system or a
         matrix coordinate system.
         """
-        
+
         direction = ax.getp('direction')
         if direction == 'ij':
             # Use matrix coordinates. The origin of the coordinate
@@ -435,12 +452,12 @@ class GnuplotBackend(BaseClass):
         if DEBUG:
             print "Setting box"
         if ax.getp('box'):
-            # display box 
+            # display box
             self._g('set border 4095 linetype -1 linewidth .4')
         else:
             # do not display box
             pass
-        
+
     def _set_grid(self, ax):
         """Turn grid lines on or off."""
         if DEBUG:
@@ -519,7 +536,7 @@ class GnuplotBackend(BaseClass):
             self._g('set palette file "%s"' % tmpf)
         else: # use default colormap
             self._g('set palette model RGB defined (0 "blue", 3 "cyan", ' \
-                    '4 "green", 5 "yellow", 8 "red", 10 "black")')        
+                    '4 "green", 5 "yellow", 8 "red", 10 "black")')
 
     def _set_view(self, ax):
         """Set viewpoint specification."""
@@ -543,7 +560,7 @@ class GnuplotBackend(BaseClass):
                 self._g('set view %d,%d' % (az,el))
             else:
                 print 'view (%s,%s) out of range [0:180,0:360]' % (az,el)
-            
+
             if cam.getp('cammode') == 'manual':
                 # for advanced camera handling:
                 roll = cam.getp('camroll')
@@ -587,6 +604,46 @@ class GnuplotBackend(BaseClass):
             self._g('unset ytics')
             self._g('unset ztics')
 
+    def _fix_latex(self, legend):
+        """
+        Translate latex syntax in title and legend to enhanced
+        PostScript symbols (enable greek letters, super- and subscripts,
+        etc.).
+        """
+        legend = legend.strip()
+        # General fix of latex syntax (more readable)
+        legend = legend.replace('**', '^')
+        #legend = legend.replace('*', '')
+        legend = legend.replace('$', '')
+        legend = legend.replace('{', '')
+        legend = legend.replace('}', '')
+        # Translate greek letters if PostScript output
+        if self._doing_PS:
+            ps2greek = dict(
+                A='Alpha', N='Nu', a='alpha',	n='nu', B='Beta', O='Omicron',
+                b='beta', o='omicron', C='Chi', P='Pi', c='chi',	p='pi',
+                D='Delta', Q='Theta', d='delta', q='theta', E='Epsilon',
+                R='Rho', e='epsilon', r='rho', F='Phi', S='Sigma', f='phi',
+                s='sigma', G='Gamma', T='Tau', g='gamma', t='tau',
+                H='Eta', U='Upsilon', h='eta', u='upsilon',
+                I='iota', W='Omega', i='iota', w='omega',
+                K='Kappa', X='Xi', k='kappa', l='lambda', x='xi',
+                L='Lambda', Y='Psi', y='psi',
+                M='Mu', Z='Zeta', m='mu', z='zeta')
+            greek2ps = {}
+            for char in ps2greek:
+                greek2ps[ps2greek[char]] = char
+
+            for greek_letter in greek2ps:
+                glb = '\\' + greek_letter
+                if glb in legend:
+                    legend = legend.replace(glb, '{/Symbol %s}' %
+                                            greek2ps[greek_letter])
+            legend = legend.replace('*', '')
+
+        legend = legend.replace('\\', '')
+        return legend
+
     def _get_linespecs(self, item):
         """
         Return the line marker, line color, line style, and
@@ -605,7 +662,7 @@ class GnuplotBackend(BaseClass):
             width = int(width)
 
         withstring = ''
-        if color is not None: 
+        if color is not None:
             if style is None:
                 if marker:
                     withstring = "points lt %d pt %d ps %d " \
@@ -615,7 +672,7 @@ class GnuplotBackend(BaseClass):
             elif style == 'lines':
                 if marker is None:  # marker is not set
                     withstring = "lines lt %d lw %d" % (color, width)
-                else: 
+                else:
                     withstring = "linespoints lt %d lw %d pt %d" % \
                                  (color, width, marker)
         else:  # no color
@@ -626,8 +683,8 @@ class GnuplotBackend(BaseClass):
                     withstring = "lines"  # no color, no style, no marker
             elif style == 'lines':
                 if marker is None:  # marker is not set
-                    withstring = "lines" 
-                else: 
+                    withstring = "lines"
+                else:
                     withstring = "linespoints pt %d" % marker
         return withstring
 
@@ -641,11 +698,11 @@ class GnuplotBackend(BaseClass):
         z = item.getp('zdata')
         # get line specifiactions:
         marker, color, style, width = self._get_linespecs(item)
-        
+
         withstring = self._get_withstring(marker, color, style, width)
         if z is not None:
             # zdata is given, add a 3D curve:
-            kwargs = {'title': item.getp('legend'),
+            kwargs = {'title': self._fix_latex(item.getp('legend')),
                       'with': withstring,
                       'using': '1:2:($3)'}
             data = Gnuplot.Data(arrayconverter(x),
@@ -655,16 +712,16 @@ class GnuplotBackend(BaseClass):
             self._g('set parametric')
         else:
             # no zdata, add a 2D curve:
-            kwargs = {'title': item.getp('legend'),
+            kwargs = {'title': self._fix_latex(item.getp('legend')),
                       'with': withstring,
                       'using': '1:($2)'}
-            
+
             data = Gnuplot.Data(arrayconverter(x),
-                                arrayconverter(y), 
+                                arrayconverter(y),
                                 **kwargs)
         return data
 
-        
+
     def _add_filled_line(self, item):
         """Add a 2D or 3D filled curve."""
         if DEBUG:
@@ -675,7 +732,7 @@ class GnuplotBackend(BaseClass):
         z = item.getp('zdata')
         # get line specifiactions:
         marker, color, style, width = self._get_linespecs(item)
-        
+
         facecolor = item.getp('facecolor')
         if not facecolor:
             facecolor = color
@@ -687,19 +744,19 @@ class GnuplotBackend(BaseClass):
             # FIXME: Should use ax.getp('fgcolor') as default edgecolor
         else:
             edgecolor = self._colors.get(edgecolor, -1)
-            
+
         withstring = self._get_withstring(marker, edgecolor, style, width)
-        
+
         if z is not None:
             # zdata is given, add a 3D curve:
-            kwargs = {'title': item.getp('legend'),
+            kwargs = {'title': self._fix_latex(item.getp('legend')),
                       'with': 'filledcurve',
                       'using': '1:2:($3)'}
             data = [Gnuplot.Data(x, y, z, **kwargs)]
             self._g('set parametric')
         else:
             # no zdata, add a 2D curve:
-            kwargs1 = {'title': item.getp('legend'),
+            kwargs1 = {'title': self._fix_latex(item.getp('legend')),
                        'with': 'filledcurve %s' % facecolor,
                        'using': '1:($2)'}
             kwargs2 = {'with': withstring, 'using': '1:($2)'}
@@ -716,7 +773,7 @@ class GnuplotBackend(BaseClass):
         y = item.getp('ydata')
         # get line specifiactions:
         marker, color, style, width = self._get_linespecs(item)
-        
+
         if rank(y) == 1:
             y = reshape(y,(len(y),1))
         nx, ny = shape(y)
@@ -768,15 +825,15 @@ class GnuplotBackend(BaseClass):
                 c = j+1
             else:
                 c = facecolor
-            kwargs = {'with': 'boxes %s' % c}
-            legend = item.getp('legend')
+            kwargs = {'with': 'boxes linecolor %s' % c}
+            legend = self._fix_latex(item.getp('legend'))
             if legend:
-                legend = eval(item.getp('legend'))[j]
+                legend = eval(self._fix_latex(item.getp('legend')))[j]
             kwargs['title'] = legend
-            #print "|%s|" % item.getp('legend')
+            #print "|%s|" % self._fix_latex(item.getp('legend'))
             # does not work:
             #kwargs = {'with': 'boxes %s' % c,
-            #          'title': item.getp('legend'),}
+            #          'title': self._fix_latex(item.getp('legend')),}
             data.append(Gnuplot.Data(x_, y_, **kwargs))
         return data
 
@@ -834,7 +891,7 @@ class GnuplotBackend(BaseClass):
         else:
             if rank(x) == 2 and rank(y) == 2:
                 x = x[:,0];  y = y[0,:]
-        kwargs = {'title': item.getp('legend'),
+        kwargs = {'title': self._fix_latex(item.getp('legend')),
                   'with': withstring,
                   'binary': 0}
         data = Gnuplot.GridData(arrayconverter(z),
@@ -854,7 +911,7 @@ class GnuplotBackend(BaseClass):
         z = item.getp('zdata')  # scalar field
 
         filled = item.getp('filled')  # draw filled contour plot if True
-        
+
         cvector = item.getp('cvector')
         clevels = item.getp('clevels')  # number of contour levels
         if cvector is None:
@@ -877,7 +934,7 @@ class GnuplotBackend(BaseClass):
                 self._g('set contour base')
             elif filled:
                 self._g('set contour base')
-                self._g('set style fill pattern')
+                self._g('set style fill solid')
                 self._g('set pm3d at s solid')
                 self._g('set palette maxcolors %d' % item.getp('clevels'))
             else:
@@ -899,7 +956,7 @@ class GnuplotBackend(BaseClass):
         else:
             if rank(x) == 2 and rank(y) == 2:
                 x = x[:,0];  y = y[0,:]
-        kwargs = {'title': item.getp('legend'),
+        kwargs = {'title': self._fix_latex(item.getp('legend')),
                   'binary': 0,
                   'with': 'l palette'}
         data = Gnuplot.GridData(arrayconverter(z),
@@ -921,7 +978,7 @@ class GnuplotBackend(BaseClass):
         u, v, w = item.getp('udata'), item.getp('vdata'), item.getp('wdata')
         # get line specifiactions (marker='.' means no marker):
         marker, color, style, width = self._get_linespecs(item)
-        
+
         withstring = 'vectors'
         if color:
             withstring += ' lt %d' % color
@@ -934,7 +991,7 @@ class GnuplotBackend(BaseClass):
 
         filled = item.getp('filledarrows') # draw filled arrows if True
 
-        if z is not None and w is not None: 
+        if z is not None and w is not None:
             # draw velocity vectors as arrows with components (u,v,w) at
             # points (x,y,z):
             data = None  # no support for vectors in 3D space in Gnuplot
@@ -959,7 +1016,8 @@ class GnuplotBackend(BaseClass):
                         y = y[:,newaxis]*ones(shape(u))
                     else:
                         y = y[newaxis,:]*ones(shape(u))
-            kwargs = {'title': item.getp('legend'), 'with': withstring}
+            kwargs = {'title': self._fix_latex(item.getp('legend')),
+                      'with': withstring}
             data = Gnuplot.Data(arrayconverter(ravel(x)),
                                 arrayconverter(ravel(y)),
                                 arrayconverter(ravel(u)),
@@ -1087,8 +1145,9 @@ class GnuplotBackend(BaseClass):
             # scitools.cfg.
             #fig._g = Gnuplot.Gnuplot(persist=1)
             fig._g = Gnuplot.Gnuplot()
-            
+
         self._g = fig._g  # link for faster access
+        self._texts = {}  # storage of text calls (dict for set)
         return fig
 
     def _replot(self):
@@ -1096,7 +1155,7 @@ class GnuplotBackend(BaseClass):
         # NOTE: only the current figure (gcf) is redrawn.
         if DEBUG:
             print "Doing replot in backend"
-        
+
         fig = self.gcf()
         # reset the plotting package instance in fig._g now if needed
         self._g.reset()
@@ -1104,11 +1163,11 @@ class GnuplotBackend(BaseClass):
         #self._g('set origin 0.0, 0.0')
         self._g('unset multiplot')
         self._g('set datafile missing "nan"')
-        
+
         self._set_figure_size(fig)
 
         if len(fig.getp('axes').items()) > 1:
-            # multiple axes
+            # multiple axes (subplot)
             self._g('set multiplot')
         nrows, ncolumns = fig.getp('axshape')
         for axnr, ax in fig.getp('axes').items():
@@ -1166,19 +1225,19 @@ class GnuplotBackend(BaseClass):
                         self._add_slices(item)
                     elif func == 'contourslice':
                         self._add_contourslices(item)
-                legend = item.getp('legend')
+                legend = self._fix_latex(item.getp('legend'))
                 if legend:
                     # add legend to plot
                     pass
 
             self._set_axis_props(ax)
-            
+
             if gdata:
                 if self._use_splot:
                     self._g.splot(gdata[0])
                 else:
                     self._g.plot(gdata[0])
-            
+
             if len(gdata) > 1:
                 for data in gdata[1:]:
                     self._g.replot(data)
@@ -1187,7 +1246,7 @@ class GnuplotBackend(BaseClass):
             # let it wait a bit when there are many curves in a plot
             if len(plotitems) > 6:
                 time.sleep(0.3)
-                
+
         if sys.platform == 'win32':
             # Since os.mkfifo is not available on the Windows platform, we
             # store a reference to the gnuplot data so that the temporary
@@ -1200,6 +1259,11 @@ class GnuplotBackend(BaseClass):
                 self._gdata = []
             self._gdata.append(gdata)
 
+        # Display texts (adds texts to latest axes, implying that this
+        # does not work well with subplots):
+        for args in self._texts:
+            self.text(*args)
+
         if self.getp('show'):
             # display plot on the screen
             if DEBUG:
@@ -1230,7 +1294,7 @@ class GnuplotBackend(BaseClass):
             'right': 'right top',
             'center': 'center center'}
         loc = mpl2gp[loc]
-        
+
         try:
             fancybox = ax.getp('legend_fancybox')
         except KeyError:
@@ -1239,7 +1303,7 @@ class GnuplotBackend(BaseClass):
         if fancybox:
             loc = loc + ' box'
         return loc
-        
+
 
     def cleanup(self):
         """Clean up data."""
@@ -1256,7 +1320,145 @@ class GnuplotBackend(BaseClass):
             (text, x, y, fontname, fontsize)
         self._g(s)
         self._g.refresh()
-        
+        self._texts[(x, y, text, fontname, fontsize)] = None
+
+    def hardcopy(self, filename, **kwargs):
+        """
+        Currently supported extensions in Gnuplot backend:
+
+          '.ps'  (PostScript)
+          '.eps' (Encapsualted PostScript)
+          '.png' (Portable Network Graphics)
+          '.pdf' (Portable Document Format)
+
+        Optional arguments for PostScript output:
+
+        ===========    =====================================================
+        Argument       Description
+        ===========    =====================================================
+        color          If True, create a plot with colors. If False
+                       (default),  create a plot in black and white.
+        enhanced       If True (default), enable enhanced text mode features
+                       like subscripts, superscripts, and mixed fonts.
+        orientation    Set orientation to 'portrait' or 'landscape'. Default
+                       is to leave this unchanged. This option has no effect
+                       on EPS or PDF output.
+        solid          If True, force lines to become solid (i.e., not
+                       dashed). Default is False.
+        fontname       Set the font to be used for titles, labels, etc.
+                       Must be a valid PostScript font or an oblique version
+                       of the Symbol font (called "Symbol-Oblique") which is
+                       useful for mathematics. Default font is "Helvetica".
+        fontsize       Set the size of the font in points. Default is 20 for
+                       for PostScript output and 8 for PDF output.
+        ===========    =====================================================
+        """
+        if DEBUG:
+            print "Hardcopy to %s" % filename
+
+        ext2term = {'.ps': 'postscript',
+                    '.eps': 'postscript',
+                    '.png': 'png'}
+
+        # check if we have a PDF terminal
+        if _check_terminal('pdfcairo'):
+            ext2term['.pdf'] = 'pdfcairo'
+            # teach Gnuplot.py about the pdfcairo terminal
+            # FIXME: This might need some tweaking. Or is this even needed?
+            Gnuplot.termdefs.terminal_opts['pdfcairo'] = [
+                Gnuplot.termdefs.KeywordOrBooleanArg(
+                    options=['landscape', 'portrait', 'eps', 'default'],
+                    argname='mode',
+                    ),
+                Gnuplot.termdefs.KeywordOrBooleanArg(options=['color', 'monochrome']),
+                Gnuplot.termdefs.KeywordOrBooleanArg(options=['solid', 'dashed']),
+                Gnuplot.termdefs.KeywordOrBooleanArg(
+                    options=['defaultplex', 'simplex', 'duplex'],
+                    argname='duplexing',
+                    ),
+                Gnuplot.termdefs.StringArg(argname='fontname'),
+                Gnuplot.termdefs.BareStringArg(argname='fontsize'),
+                ]
+        elif _check_terminal('pdf'):
+            ext2term['.pdf'] = 'pdf'
+
+        basename, ext = os.path.splitext(filename)
+        if not ext:
+            # no extension given, assume .ps:
+            ext = '.ps'
+            filename += ext
+        elif ext not in ext2term:
+            raise ValueError("hardcopy: extension must be %s, not '%s'" % \
+                             (ext2term.keys(), ext))
+        terminal = ext2term.get(ext, 'postscript')
+
+        self.setp(**kwargs)
+        color = self.getp('color')
+        enhanced = kwargs.get('enhanced', True)
+        orientation = kwargs.get('orientation', None)
+        solid = kwargs.get('solid', False)
+        fontname = kwargs.get('fontname', 'Helvetica')
+        keyw = {'filename': filename, 'terminal': terminal}
+
+        # Create a new Gnuplot instance only for now
+        self._g = Gnuplot.Gnuplot()
+        setterm = ['set', 'terminal', terminal]
+        if terminal == 'postscript':
+            fontsize = kwargs.get('fontsize', 20)
+            keyw.update({'color': color, 'enhanced': enhanced, 'solid': solid,
+                         'fontname': fontname, 'fontsize': fontsize})
+            if ext == '.eps':
+                keyw['mode'] = 'eps'
+                setterm.append('eps')
+            else:
+                if orientation in ['landscape', 'portrait']:
+                    keyw['mode'] = orientation
+                    setterm.append(orientation)
+            setterm.append(enhanced and 'enhanced' or 'noenhanced')
+            setterm.append(color and 'color' or 'monochrome')
+            setterm.append(solid and 'solid' or 'dashed')
+            setterm.append(' dashlength 5 linewidth 3')  # look best
+            #setterm.append(' dashlength 5 linewidth 4')
+            setterm.append('"%s"' % fontname)
+            setterm.append('%s' % fontsize)
+            self._doing_PS = True
+        elif terminal == 'pdf':
+            fontsize = kwargs.get('fontsize', 8)
+            setterm.append(color and 'color' or 'monochrome')
+            setterm.append(enhanced and 'enhanced' or 'noenhanced')
+            setterm.append('font "%s,%s"' % (fontname, fontsize))
+            setterm.append('linewidth 4')
+            setterm.append(solid and 'solid' or 'dashed')
+            setterm.append('dl 3')  # dashlength
+            # FIXME: Should self._doing_PS be True or False in this case?
+            self._doing_PS = True
+        elif terminal == 'pdfcairo':
+            fontsize = kwargs.get('fontsize', 8)
+            setterm.append(enhanced and 'enhanced' or 'noenhanced')
+            setterm.append(color and 'color' or 'mono')
+            setterm.append(solid and 'solid' or 'dashed')
+            setterm.append('font "%s,%s"' % (fontname, fontsize))
+            setterm.append('linewidth 4')
+            setterm.append('dashlength 3')
+            # FIXME: Should self._doing_PS be True or False in this case?
+            self._doing_PS = True
+        elif terminal == 'png':
+            pass
+        self._g(' '.join(setterm))
+        self._g('set output "%s"' % filename)
+        self._replot()
+        if len(self.gcf().getp('axes')) == 1:
+            # Need to call hardcopy in Gnuplot.py to avoid ending up with
+            # a PostScript file with multiple pages:
+            self._g.hardcopy(**keyw)
+        self._g('quit')
+        self._g = self.gcf()._g  # set self._g to the correct instance again
+        self._doing_PS = False
+
+        if self.getp('interactive') and self.getp('show'):
+            self._replot()
+
+
     def hardcopy_old(self, filename, **kwargs):
         """
         Currently supported extensions in Gnuplot backend:
@@ -1288,15 +1490,15 @@ class GnuplotBackend(BaseClass):
             raise ValueError("hardcopy: extension must be %s, not '%s'" % \
                              (ext2term.keys(), ext))
         terminal = ext2term.get(ext, 'postscript')
-        
+
         self.setp(**kwargs)
         fontname = kwargs.get('fontname', 'Helvetica')
         fontsize = kwargs.get('fontsize', 16)
         orientation = kwargs.get('orientation', 'landscape')
         color = self.getp('color')
-                  
+
         self._g('unset multiplot') # is this necessary?
-        
+
         if self.getp('show'): # OK to display to screen
             self._replot()
             kwargs = {'filename': filename, 'terminal': terminal}
@@ -1313,12 +1515,12 @@ class GnuplotBackend(BaseClass):
                 colortype = 'color'
             else:
                 colortype = 'monochrome'
-                        
+
             # Create a new Gnuplot instance only for now
             self._g = Gnuplot.Gnuplot()
             kwargs = {'filename': filename, 'terminal': terminal}
             if terminal == 'postscript':
-                kwargs.update({'color': color, 'enhanced': True, 
+                kwargs.update({'color': color, 'enhanced': True,
                                'fontname': fontname, 'fontsize': fontsize})
                 if ext == '.eps':
                     self._g('set term postscript eps %s' % colortype)
@@ -1335,95 +1537,6 @@ class GnuplotBackend(BaseClass):
             self._g('quit')
             self._g = self.gcf()._g # set _g to the correct instance again
 
-    def hardcopy(self, filename, **kwargs):
-        """
-        Currently supported extensions in Gnuplot backend:
-
-          '.ps'  (PostScript)
-          '.eps' (Encapsualted PostScript)
-          '.png' (Portable Network Graphics)
-
-        Optional arguments for PostScript output:
-
-          color       -- If True, create a plot with colors. If False
-                         (default),  create a plot in black and white.
-          enhanced    -- If True (default), enable enhanced text mode features
-                         like subscripts, superscripts, and mixed fonts. 
-          orientation -- Set orientation to 'portrait' or 'landscape'. Default
-                         is to leave this unchanged. This option has no effect
-                         on EPS output.
-          solid       -- If True, force lines to become solid (i.e., not
-                         dashed). Default is False.
-          fontname    -- Set the font to be used for titles, labels, etc.
-                         Must be a valid PostScript font or an oblique version
-                         of the Symbol font (called "Symbol-Oblique") which is
-                         useful for mathematics. Default font is "Helvetica".
-          fontsize    -- Set the size of the font in PostScript points.
-                         Default is 14.
-        """
-        if DEBUG:
-            print "Hardcopy to %s" % filename
-
-        ext2term = {'.ps': 'postscript',
-                    '.eps': 'postscript',
-                    '.png': 'png'}
-        basename, ext = os.path.splitext(filename)
-        if not ext:
-            # no extension given, assume .ps:
-            ext = '.ps'
-            filename += ext
-        elif ext not in ext2term:
-            raise ValueError("hardcopy: extension must be %s, not '%s'" % \
-                             (ext2term.keys(), ext))
-        terminal = ext2term.get(ext, 'postscript')
-        
-        self.setp(**kwargs)
-        color = self.getp('color')
-        enhanced = kwargs.get('enhanced', True)
-        orientation = kwargs.get('orientation', None)
-        solid = kwargs.get('solid', False)
-        fontname = kwargs.get('fontname', 'Helvetica')
-        fontsize = kwargs.get('fontsize', 20)
-        
-        keyw = {'filename': filename, 'terminal': terminal}
-        if terminal == 'postscript':
-            keyw.update({'color': color, 'enhanced': enhanced, 'solid': solid, 
-                       'fontname': fontname, 'fontsize': fontsize})
-            if orientation in ['landscape', 'portrait']:
-                keyw['mode'] = orientation
-            if ext == '.eps':
-                keyw['mode'] = 'eps'
-                        
-        # Create a new Gnuplot instance only for now
-        self._g = Gnuplot.Gnuplot()
-        setterm = ['set', 'terminal', terminal]
-        if terminal == 'postscript':
-            if ext == '.eps':
-                setterm.append('eps')
-            else:
-                if orientation in ['landscape', 'portrait']:
-                    setterm.append(orientation)
-            setterm.append(enhanced and 'enhanced' or 'noenhanced')
-            setterm.append(color and 'color' or 'monochrome')
-            setterm.append(solid and 'solid' or 'dashed')
-            setterm.append(' dashlength 3 linewidth 1.2 ')
-            setterm.append('"%s"' % fontname)
-            setterm.append('%s' % fontsize)
-        elif terminal == 'png':
-            pass
-        self._g(' '.join(setterm))
-        self._g('set output "%s"' % filename)
-        self._replot()
-        if len(self.gcf().getp('axes')) == 1:
-            # Need to call hardcopy in Gnuplot.py to avoid ending up with
-            # a PostScript file with multiple pages:
-            self._g.hardcopy(**keyw)
-        self._g('quit')
-        self._g = self.gcf()._g  # set self._g to the correct instance again
-        
-        if self.getp('interactive') and self.getp('show'):
-            self._replot()
-
     # reimplement methods like clf, closefig, closefigs
     def clf(self):
         """Clear current figure."""
@@ -1453,27 +1566,27 @@ class GnuplotBackend(BaseClass):
     def hsv(self, m=0):
         c = 'rgbformulae 3,2,2'
         return 'set palette model HSV maxcolors %d %s' % (m,c)
-    
+
     def hot(self, m=0):
         c = 'rgbformulae 21,22,23'
         return 'set palette model RGB maxcolors %d %s' % (m,c)
-    
+
     def gray(self, m=0):
         c = 'defined (0 "black", 1 "white")'
         return 'set palette model RGB maxcolors %d %s' % (m,c)
-    
+
     def bone(self, m=0):
         c = 'defined (0 "black", 4 "light-blue", 5 "white")'
         return 'set palette model RGB maxcolors %d %s' % (m,c)
-    
+
     def copper(self, m=0):
         c = 'defined (0 "black", 1 "coral")'
         return 'set palette model RGB maxcolors %d %s' % (m,c)
-    
+
     def pink(self, m=0):
         c = 'defined (0 "black", 1 "pink", 8 "pink", 10 "white")'
         return 'set palette model RGB maxcolors %d %s' % (m,c)
-    
+
     def white(self, m=64):
         c = 'defined (0 "white", 1 "white")'
         return 'set palette model RGB maxcolors %d %s' % (m,c)
@@ -1482,7 +1595,7 @@ class GnuplotBackend(BaseClass):
 ##         else:
 ##             cmap = []
 ##         return cmap
-    
+
     def flag(self, m=0):
         colors = "red,white,blue,black".split(',')
         j=k=0
@@ -1495,7 +1608,7 @@ class GnuplotBackend(BaseClass):
             k += 1
         c = c[:-2]+')'
         return 'set palette model RGB maxcolors %d %s' % (m,c)
-                
+
     def lines(self, m=0):
         # NOTE: not finished
         colors = "blue,green,red,cyan,magenta,yellow,black".split(',')
@@ -1512,7 +1625,7 @@ class GnuplotBackend(BaseClass):
         c = c[:-2]+')'
         #print c
         return 'set palette model RGB maxcolors %d %s' % (m,c)
-    
+
     def colorcube(self, m=0):
         colors = "white,black,gray0,gray10,grey20,grey30,gray40,gray50,"\
                  "gray60,grey70,grey80,gray90,grey100,grey,light-grey,"\
@@ -1533,38 +1646,38 @@ class GnuplotBackend(BaseClass):
             c += ', %d "%s", %d "%s"' % (j,colors[i-1],j,colors[i])
         c += ')'
         return 'set palette model RGB maxcolors %d %s' % (m,c)
-    
+
     def vga(self, m=0):
         return None
-    
+
     def jet(self, m=0):
         c = 'defined (0 "blue", 3 "cyan", 4 "green", 5 "yellow", '\
             '8 "red", 10 "black")' # stop at red (remove black)
         return 'set palette model RGB maxcolors %d %s' % (m,c)
-    
+
     def prism(self, m=0):
         return None
 
     def cool(self, m=0):
         c = 'defined (0 "cyan", 1 "magenta")'
         return 'set palette model RGB maxcolors %d %s' % (m,c)
-    
+
     def autumn(self, m=0):
         c = 'defined (0 "red", 1 "yellow")'
         return 'set palette model RGB maxcolors %d %s' % (m,c)
-    
+
     def spring(self, m=0):
         c = 'defined (0 "magenta", 1 "yellow")'
         return 'set palette model RGB maxcolors %d %s' % (m,c)
-    
+
     def winter(self, m=0):
         c = 'defined (0 "blue", 1 "spring-green")'
         return 'set palette model RGB maxcolors %d %s' % (m,c)
-    
+
     def summer(self, m=0):
         c = 'defined (0 "green", 1 "yellow")'
         return 'set palette model RGB maxcolors %d %s' % (m,c)
-    
+
 
     # Now we add the doc string from the methods in BaseClass to the
     # methods that are reimplemented in this backend:
@@ -1581,7 +1694,7 @@ class GnuplotBackend(BaseClass):
                         m2.__doc__ = ""
                     m2.__doc__ = m1.__doc__ + m2.__doc__
 
-    
+
 plt = GnuplotBackend()  # create backend instance
 use(plt, globals())     # export public namespace of plt to globals()
 backend = os.path.splitext(os.path.basename(__file__))[0][:-1]
