@@ -29,10 +29,11 @@ from __future__ import division
 from common import *
 from scitools.numpyutils import floor, linspace, array
 from scitools.globaldata import DEBUG, VERBOSE
-from scitools.misc import test_if_module_exists 
+from scitools.misc import test_if_module_exists
 from misc import _update_from_config_file
 
 test_if_module_exists('matplotlib', msg='You need to install the Matplotlib package.', abort=False)
+
 import matplotlib
 import matplotlib.colors
 # Override values from the matplotlib configuration file with values
@@ -49,10 +50,10 @@ class MatplotlibBackend(BaseClass):
     def __init__(self):
         BaseClass.__init__(self)
         self._init()
-        
+
     def _init(self, *args, **kwargs):
         """Perform initialization that is special for this backend."""
-        
+
         self.figure(self.getp('curfig'))
 
         # conversion tables for format strings:
@@ -120,6 +121,9 @@ class MatplotlibBackend(BaseClass):
         xlabel = ax.getp('xlabel')
         ylabel = ax.getp('ylabel')
         zlabel = ax.getp('zlabel')
+        xlabel = self._fix_latex(xlabel)
+        ylabel = self._fix_latex(ylabel)
+        zlabel = self._fix_latex(zlabel)
         if xlabel:
             # add a text label on x-axis
             self._g.xlabel(xlabel)
@@ -129,16 +133,18 @@ class MatplotlibBackend(BaseClass):
         if zlabel:
             # add a text label on z-axis
             pass
-        
+
     def _set_title(self, ax):
         """Add a title at the top of the axis."""
         if DEBUG:
             print "Setting title"
         title = ax.getp('title')
-        title = self._fix_latex(title)
+        # The title can be a mix of math and text, leave this
+        # to the user
+        #title = self._fix_latex(title)
         if title:
             self._g.title(title)
-    
+
     def _set_limits(self, ax):
         """Set axis limits in x, y, and z direction."""
         if DEBUG:
@@ -207,12 +213,19 @@ class MatplotlibBackend(BaseClass):
         """Set data aspect ratio."""
         if ax.getp('daspectmode') == 'manual':
             dar = ax.getp('daspect')  # dar is a list (len(dar) is 3).
-            self._g.gca().set_aspect(dar[0])
+            xmin = ax.getp('xmin')
+            xmax = ax.getp('xmax')
+            ymin = ax.getp('ymin')
+            ymax = ax.getp('ymax')
+            r = float(xmax-xmin)/(ymax-ymin)
+            self._g.gca().set_aspect(r*dar[0])
+        elif ax.getp('daspectmode') == 'equal':
+            self._g.gca().set_aspect('equal')
         else:
             # daspectmode is 'auto'. Plotting package handles data
             # aspect ratio automatically.
             self._g.gca().set_aspect('auto')
-        
+
     def _set_axis_method(self, ax):
         method = ax.getp('method')
         if method == 'equal':
@@ -237,7 +250,7 @@ class MatplotlibBackend(BaseClass):
         Use either the default Cartesian coordinate system or a
         matrix coordinate system.
         """
-        
+
         direction = ax.getp('direction')
         if direction == 'ij':
             # Use matrix coordinates. The origin of the coordinate
@@ -257,16 +270,20 @@ class MatplotlibBackend(BaseClass):
         if DEBUG:
             print "Setting box"
         if ax.getp('box'):
-            # display box 
+            # display box
             self._g.box(on=True)
         else:
             # do not display box
             self._g.box(on=False)
-        
+
     def _set_grid(self, ax):
         """Turn grid lines on or off."""
         if DEBUG:
             print "Setting grid"
+        if self._mpl3D:
+            # Do not call self._g.grid for 3D surf plots
+                return
+
         if ax.getp('grid'):
             # turn grid lines on
             self._g.grid(b=True)
@@ -289,6 +306,10 @@ class MatplotlibBackend(BaseClass):
         """Add a colorbar to the axis."""
         if DEBUG:
             print "Setting colorbar"
+        if self._mpl3D:
+            # Do not call self._g.grid for 3D surf plots
+                return
+
         cbar = ax.getp('colorbar')
         if cbar.getp('visible'):
             # turn on colorbar
@@ -314,7 +335,10 @@ class MatplotlibBackend(BaseClass):
             if cmin is None or cmax is None:
                 cmin, cmax = [0,1]
             # set color axis scaling according to cmin and cmax
-            self._g.clim(cmin,cmax)
+            if self._mplsurf is not None:
+                pass # cannot handle 3D surf
+            else:
+                self._g.clim(cmin,cmax)
         else:
             # use autoranging for color axis scale
             pass
@@ -325,7 +349,7 @@ class MatplotlibBackend(BaseClass):
             print "Setting colormap"
         cmap = ax.getp('colormap')
         # cmap is plotting package dependent
-        # the colormap is set in 
+        # the colormap is set in
 
     def _set_view(self, ax):
         """Set viewpoint specification."""
@@ -347,7 +371,7 @@ class MatplotlibBackend(BaseClass):
             else:
                 # set a 3D view according to az and el
                 pass
-            
+
             if cam.getp('cammode') == 'manual':
                 # for advanced camera handling:
                 roll = cam.getp('camroll')
@@ -397,10 +421,21 @@ class MatplotlibBackend(BaseClass):
 
     def _fix_latex(self, legend):
         """Enclose legend in $$ if latex syntax is detected."""
-        if not matplotlib.rcParams['text.usetex']:
-            return legend
+        # We always support latex syntax either through direct
+        # use of latex (text.usetex=true) or through the native mathtext.
+        #if not matplotlib.rcParams['text.usetex']:
+        #    return legend
+
         legend = legend.strip()
         if len(legend) >= 2 and legend[0] != '$' and legend[-1] != '$':
+            # else: assume correct latex syntax, otherwise fix
+            #print '....fix', legend,
+            if '**' in legend:
+                legend = legend.replace('**', '^')
+            if '*' in legend:
+                #legend = legend.replace('*', '\\cdot')
+                legend = legend.replace('*', ' ')
+
             chars = '\\', '^', '_'
             latex = False
             for c in chars:
@@ -412,9 +447,13 @@ class MatplotlibBackend(BaseClass):
                 legend = '$' + legend + '$'
 
                 # enclose words in \hbox{}'es:
-                word = r'(\s?[A-Za-z][a-z]*[ :;,$] ?)'
-                if re.search(word, legend):
-                    legend = re.sub(word, r'\hbox{\g<1>}', legend)
+                # (not successful enough)
+                #word = r'(\s?[^\\][A-Za-z][a-z]*[ :;,$)] ?)'
+                #word = r'(\s?[A-Za-z][a-z]*[ :;,$)])'
+                #word = r'(\w[ :;,$)])'
+                #word = r'(\b[A-Za-z][a-z]*[ :;,$)]\b)'
+                #if re.search(word, legend):
+                #    legend = re.sub(word, r'\hbox{\g<1>}', legend)
                 # remove internal $ chars:
                 legend = legend.replace('$', '')
                 legend = '$' + legend + '$'
@@ -428,16 +467,11 @@ class MatplotlibBackend(BaseClass):
                         'sinh', 'cosh', 'tanh'
                 for func in funcs:
                     legend = _fix_func(func, func, legend)
-                funcs = [('atan', 'arctan'), ('asin', 'arcsin'), 
+                funcs = [('atan', 'arctan'), ('asin', 'arcsin'),
                          ('acos', 'arccos'),]
                 for func, newfunc in funcs:
                     legend = _fix_func(func, newfunc, legend)
-                if '**' in legend:
-                    legend = legend.replace('**', '^')
-                if '*' in legend:
-                    #legend = legend.replace('*', '\\cdot')
-                    legend = legend.replace('*', ' ')
-                #print 'latex fix:', legend
+                #print 'after fix:', legend
         return legend
 
     def _add_line(self, item):
@@ -482,7 +516,7 @@ class MatplotlibBackend(BaseClass):
 
         if not width:
             width = 1.0
-            
+
         facecolor = item.getp('facecolor')
         if not facecolor:
             if not color:
@@ -495,10 +529,10 @@ class MatplotlibBackend(BaseClass):
         opacity = item.getp('material').getp('opacity')
         if opacity is None:
             opacity = 1.0
-            
+
         if z is not None:
             # zdata is given, add a filled 3D curve:
-            print "No support for fill3 in Matplotlib."            
+            print "No support for fill3 in Matplotlib."
         else:
             # no zdata, add a filled 2D curve:
             l = self._g.fill(x, y, fc=facecolor, ec=edgecolor,
@@ -566,7 +600,8 @@ class MatplotlibBackend(BaseClass):
         else:
             self._g.xticks(range(len(x)), barticks)
 
-    def _add_surface(self, item, shading='faceted', colormap=None):
+    def _add_surface(self, item, shading='faceted', colormap=None,
+                     showcolorbar=False, zmin=None, zmax=None):
         if DEBUG:
             print "Adding a surface"
         x = squeeze(item.getp('xdata'))  # grid component in x-direction
@@ -586,7 +621,7 @@ class MatplotlibBackend(BaseClass):
         opacity = item.getp('material').getp('opacity')
         if opacity is None:
             opacity = 1.0
-        
+
         contours = item.getp('contours')
         if contours:
             # the current item is produced by meshc or surfc and we
@@ -596,12 +631,37 @@ class MatplotlibBackend(BaseClass):
 
         if item.getp('wireframe'):
             # wireframe mesh (as produced by mesh or meshc)
-            print "No support for mesh/meshc in Matplotlib."
+            fig = self._g.gcf()
+            ax = fig.gca(projection='3d')
+            h = ax.plot_wireframe(x, y, z)
+            if legend:
+                h.set_label(legend)
         else:
             # colored surface (as produced by surf, surfc, or pcolor)
             # use keyword argument shading to set the color shading mode
-            h = self._g.pcolor(x, y, z, shading=shading,
-                               cmap=colormap, alpha=opacity)
+            function = item.getp('function')
+            if function == 'pcolor':
+                h = self._g.pcolor(x, y, z, shading=shading,
+                                   cmap=colormap, alpha=opacity)
+            else:
+                # This is really a hack to use 3D surfaces in matplotlib...
+                from mpl_toolkits.mplot3d import Axes3D
+                fig = self._g.gcf()
+                ax = fig.gca(projection='3d')
+                if self._mplsurf is not None:
+                    ax.collections.remove(self._mplsurf)
+                self._mplsurf = ax.plot_surface(x, y, z, rstride=1, cstride=1,
+                                                linewidth=0, cmap=colormap,
+                                                antialiased=False)
+                if showcolorbar and not self._mpl3D:
+                    # Show colorbar only for the first plot in an animation
+                    fig.colorbar(self._mplsurf, shrink=1.0, aspect=15,
+                                 orientation='vertical',)
+                if zmin is not None and zmax is not None:
+                    ax.set_zlim3d(zmin, zmax)
+                self._mpl3D = True
+                # Problem: cannot fix color scale (or?)
+
             if legend:
                 h.set_label(legend)
 
@@ -619,15 +679,15 @@ class MatplotlibBackend(BaseClass):
 
         if colormap is None or colormap == 'default':
             colormap = self._g.cm.get_cmap('jet')
-        
+
         if shape(x) != shape(z) or shape(y) != shape(z):
             x, y = meshgrid(x, y, sparse=False,
                             indexing=item.getp('indexing'))
-        
+
         opacity = item.getp('material').getp('opacity')
         if opacity is None:
             opacity = 1.0
-        
+
         filled = item.getp('filled')  # draw filled contour plot if True
 
         cvector = item.getp('cvector')
@@ -654,7 +714,7 @@ class MatplotlibBackend(BaseClass):
         if filled:
             contour_cmd = self._g.contourf
         kwargs = {'cmap': colormap, 'alpha': opacity}
-        
+
         # get line specifiactions:
         marker, color, style, width = self._get_linespecs(item)
         if color:
@@ -671,7 +731,7 @@ class MatplotlibBackend(BaseClass):
         if item.getp('clabels'):
             # add labels on the contour curves
             self._g.clabel(cs)
-    
+
     def _add_vectors(self, item):
         if DEBUG:
             print "Adding vectors"
@@ -809,7 +869,7 @@ class MatplotlibBackend(BaseClass):
         # Extension of BaseClass.figure:
         # add a plotting package figure instance as fig._g and create a
         # link to it as self._g
-        fignum = BaseClass.figure(self, *args, **kwargs) 
+        fignum = BaseClass.figure(self, *args, **kwargs)
         fig = self.gcf()
         try:
             fig._g
@@ -821,40 +881,44 @@ class MatplotlibBackend(BaseClass):
                 print "creating figure %s in backend" % name
 
             fig._g = pylab
-            
+
         self._g = fig._g # link for faster access
+        self._mpl3D = False
+        self._mplsurf = None
+        self._texts = {}  # store calls to text (for replot)
         return fignum
-        
+
     def _replot(self):
         """Replot all axes and all plotitems in the backend."""
         # NOTE: only the current figure (gcf) is redrawn.
         if DEBUG:
             print "Doing replot in backend"
 
-        # turn off interactive in pylab temporarily:
+        # turn off interactive in pyplot temporarily:
         old_pylab_interactive_state = self._g.isinteractive()
         self._g.ioff()
-        
+
         fig = self.gcf()
         try:
             fig._g
-        except: 
+        except:
             self.figure(self.getp('curfig'))
         self._g.figure(self.getp('curfig'))
 
         # reset the plotting package instance in fig._g now if needed
-        self._g.clf()
-        
+        if not self._mpl3D:
+            self._g.clf()
+
         self._set_figure_size(fig)
-        
+
         nrows, ncolumns = fig.getp('axshape')
         for axnr, ax in fig.getp('axes').items():
             if ax.getp('numberofitems') == 0:
                 continue
             if nrows != 1 or ncolumns != 1:
                 # create axes in tiled position
-                # this is subplot(nrows,ncolumns,axnr)
-                self._g.subplot(nrows,ncolumns,axnr)
+                # this is subplot(nrows, ncolumns, axnr)
+                self._g.subplot(nrows, ncolumns, axnr)
             else:
                 rect = ax.getp('viewport')
                 if isinstance(rect, (list,tuple)) and len(rect) == 4 and \
@@ -874,8 +938,11 @@ class MatplotlibBackend(BaseClass):
                     self._add_bar_graph(item, shading=ax.getp('shading'))
                 elif isinstance(item, Surface):
                     self._add_surface(item,
-                                      shading=ax.getp('shading'),
-                                      colormap=ax.getp('colormap'))
+                      shading=ax.getp('shading'),
+                      colormap=ax.getp('colormap'),
+                      showcolorbar=ax.getp('colorbar').getp('visible'),
+                      zmin=ax.getp('zmin'),
+                      zmax=ax.getp('zmax'))
                 elif isinstance(item, Contours):
                     self._add_contours(item, colormap=ax.getp('colormap'))
                 elif isinstance(item, VelocityVectors):
@@ -909,7 +976,12 @@ class MatplotlibBackend(BaseClass):
                 self._g.legend(loc=loc, fancybox=fancybox)
 
             self._set_axis_props(ax)
-                    
+
+        # Display texts
+        for args in self._texts:
+            self.text(args[0], args[1], args[2],
+                      fontname=args[3], fontsize=args[4])
+
         # set back the interactive state in pylab:
         if old_pylab_interactive_state:
             self._g.ion()
@@ -930,7 +1002,8 @@ class MatplotlibBackend(BaseClass):
              fontsize=Axis._local_prop['fontsize']):
         """Write text at position (x,y) in a curveplot."""
         self._g.text(x, y, text, family=fontname, size=fontsize)
-        
+        self._texts[(x, y, text, fontname, fontsize)] = None
+
 
     def hardcopy(self, filename, **kwargs):
         """
@@ -961,11 +1034,11 @@ class MatplotlibBackend(BaseClass):
                         edgecolor='w',
                         orientation=orientation)
 
-    def clf(self): 
+    def clf(self):
         self._g.clf()
         BaseClass.clf(self)
 
-    def closefig(self, arg=None): 
+    def closefig(self, arg=None):
         if arg is None:
             num = self.getp('curfig')  # close current figure
         elif arg in self._figs.keys():
@@ -980,7 +1053,7 @@ class MatplotlibBackend(BaseClass):
         self._g.close(num)
         #del self._figs[num]._g
         #del self._figs[num]
-    
+
     def closefigs(self):
         for key in self._figs.keys():
             self.closefig(key)
@@ -993,10 +1066,10 @@ class MatplotlibBackend(BaseClass):
 
     def hot(self, m=None):
         return pylab.cm.get_cmap('hot', m)
-    
+
     def gray(self, m=None):
         return pylab.cm.get_cmap('gray', m)
-    
+
     def bone(self, m=None):
         return pylab.cm.get_cmap('bone', m)
 
@@ -1005,47 +1078,47 @@ class MatplotlibBackend(BaseClass):
 
     def pink(self, m=None):
         return pylab.cm.get_cmap('pink', m)
-    
+
     def white(self, m=None):
         raise NotImplementedError('white not implemented in class %s' % \
                                   self.__class__.__name__)
-    
+
     def flag(self, m=None):
         return pylab.cm.get_cmap('flag', m)
-    
+
     def lines(self, m=None):
         raise NotImplementedError('lines not implemented in class %s' % \
                                   self.__class__.__name__)
-    
+
     def colorcube(self, m=None):
         raise NotImplementedError('colorcube not implemented in class %s' % \
                                   self.__class__.__name__)
-    
+
     def vga(self, m=None):
         raise NotImplementedError('vga not implemented in class %s' % \
                                   self.__class__.__name__)
-    
+
     def jet(self, m=None):
         return pylab.cm.get_cmap('jet', m)
-    
+
     def prism(self, m=None):
         return pylab.cm.get_cmap('prism', m)
-    
+
     def cool(self, m=None):
         return pylab.cm.get_cmap('cool', m)
-    
+
     def autumn(self, m=None):
         return pylab.cm.get_cmap('autumn', m)
-    
+
     def spring(self, m=None):
         return pylab.cm.get_cmap('spring', m)
-    
+
     def winter(self, m=None):
         return pylab.cm.get_cmap('winter', m)
-    
+
     def summer(self, m=None):
         return pylab.cm.get_cmap('summer', m)
-    
+
 
     # Now we add the doc string from the methods in BaseClass to the
     # methods that are reimplemented in this backend:
@@ -1062,7 +1135,7 @@ class MatplotlibBackend(BaseClass):
                         m2.__doc__ = ""
                     m2.__doc__ = m1.__doc__ + m2.__doc__
 
-    
+
 plt = MatplotlibBackend()  # create backend instance
 use(plt, globals())        # export public namespace of plt to globals()
 
