@@ -6,6 +6,10 @@ from scitools.misc import findprograms
 from misc import _check_type
 
 class MovieEncoder(object):
+    """
+    Class for turning a series of filenames with frames in a movie into
+    a movie file.
+    """
     _local_prop = {
         'input_files': None,         # image files
         'output_file': None,         # resulting movie
@@ -30,8 +34,8 @@ class MovieEncoder(object):
         'force_conversion': False,   # force conversion (to png) if True
         'cleanup': True,             # clean up temporary files
         }
-    _legal_encoders = 'mencoder ffmpeg mpeg_encode ppmtompeg mpeg2enc '\
-                      'convert'.split()
+    _legal_encoders = 'convert mencoder ffmpeg mpeg_encode ppmtompeg '\
+                      'mpeg2enc html'.split()
     _legal_file_types = 'png gif jpg ps eps bmp tif tga pnm'.split()
 
     def __init__(self, input_files, **kwargs):
@@ -42,30 +46,29 @@ class MovieEncoder(object):
             if key in self._prop:
                 self._prop[key] = kwargs[key]
 
-        # provide some space before print statements:
-        print '\n\n\n'
+        print '\n\n' # provide some space before print statements
 
-        # determine which encoder to be used:
+        # Determine which encoder to be used
         encoder = self._prop['encoder']
         if encoder is None:
+            # No encoder given, find the first installed among the legal ones
             for enc in self._legal_encoders:
                 if findprograms(enc):
                     encoder = enc
                     break
             if encoder is None:
-                raise Exception("None of the supported encoders are installed."\
-                                "Please install an encoder from this list:\n%s"\
-                                 % (', '.join(_legal_encoders)))
+                # No encoder is installed, fall back on html
+                encoder = 'html'
             self._prop['encoder'] = encoder
         else:
             if not encoder in self._legal_encoders:
-                raise ValueError("encoder must be %s, not '%s'" % \
+                raise ValueError("encoder must be %s, not '%s'" %
                                  (self._legal_encoders, encoder))
-            if not findprograms(encoder):
+            if not encoder.startswith('html') and not findprograms(encoder):
                 raise Exception("The selected encoder (%s) is not installed" \
                                 % encoder)
 
-        # determine the file type of the input files:
+        # Determine the file type of the input files
         if isinstance(input_files, (tuple,list)):
             file_ = input_files[0]
         elif isinstance(input_files, str):
@@ -75,9 +78,9 @@ class MovieEncoder(object):
                              "list/tuple of strings or a string, not '%s'" % \
                              type(input_files))
 
-        # check that the input files do exist:
+        # Check that the input files do exist
         if isinstance(input_files, str):
-            # are input_files on ffmpeg/mpeg2enc format or Unix wildcard format?
+            # Are input_files on ffmpeg/mpeg2enc format or Unix wildcard format?
             ffmpeg_format = r'(.+)%\d+d(\..+)'
             m = re.search(ffmpeg_format, input_files, re.DOTALL)
             if m:
@@ -89,7 +92,7 @@ class MovieEncoder(object):
                 print 'No files of the form %s exist.' % input_files
             else:
                 print 'Found %d files of the format %s.' % \
-                      (len(all_input_files), input_files)
+                (len(all_input_files), input_files)
         else:  # list of specific filenames
             all_input_files = input_files
         error_encountered = False
@@ -108,19 +111,40 @@ class MovieEncoder(object):
             raise TypeError("File type must be %s, not '%s'" % \
                             (self._legal_file_types, file_type))
         self._prop['file_type'] = file_type
-        
+
     def encode(self):
         """Encode a series of images to a movie."""
-        # check that the selected encoder is legal:
         encoder = self._prop['encoder']
-        if not encoder in self._legal_encoders:
-            raise ValueError("Encoder must be one of %s, not '%s'" % \
-                             (self._legal_encoders, encoder))
 
-        # get command string:
+        if encoder == 'html':
+            # Don't make movie file, just an html file that can play png files
+            files = self._prop['input_files']
+            if isinstance(files, str):
+                files = glob.glob(files)
+                files.sort()
+            print '\nMaking HTML code for displaying', ', '.join(files)
+            fps = self._prop['fps']
+            interval_ms = 1000.0/fps
+            outf = self._prop['output_file']
+            if outf is None:
+                outf = 'movie.html'
+            else:
+                # Ensure .html extension
+                outf = os.path.splitext(outf)[0] + '.html'
+            casename = os.path.splitext(outf)[0]
+            header, jscode, form, footer = \
+                html_movie(files, interval_ms, casename=casename)
+
+            f = open(outf, 'w')
+            f.write(header + jscode + form + footer)
+            f.close()
+            print "\n\nmovie in output file", outf
+            return
+
+        # Get command string (all other encoders are run as stand-alone apps)
         exec('cmd=self._%s()' % encoder)
 
-        # run command:
+        # Run command
         if not self._prop['quiet']:
             print "\nscitools.easyviz.movie function runs the command: \n\n%s\n" % cmd
         failure = os.system(cmd)
@@ -129,9 +153,9 @@ class MovieEncoder(object):
             raise SystemError('Check error messages from the encoder in the terminal window')
         elif not self._prop['quiet']:
             print "\n\nmovie in output file", self._prop['output_file']
-            
-        # clean up temporary files:
-        if self._prop['cleanup'] and hasattr(self, '_tmp_files'): 
+
+        # Clean up temporary files
+        if self._prop['cleanup'] and hasattr(self, '_tmp_files'):
             for tmp_file in self._tmp_files:
                 os.remove(tmp_file)
 
@@ -149,7 +173,7 @@ class MovieEncoder(object):
         size = self._get_size()
         if size is not None:
             cmd += ' -scale %sx%s' % (size[0], size[1])
-        
+
         # get image files:
         files = self._prop['input_files']
         if isinstance(files, str):
@@ -166,12 +190,17 @@ class MovieEncoder(object):
             raise ValueError(
                 "'%s' is not a valid file specification or the files " \
                 "does not exist." % files)
-        cmd += ' %s' % (' '.join(files))
+        if isinstance(self._prop['input_files'], str):
+            cmd += ' ' + self._prop['input_files']
+        else:
+            cmd += ' %s' % (' '.join(files))
 
         # set output file:
         if self._prop['output_file'] is None:
             self._prop['output_file'] = 'movie.gif'
         output_file = self._prop['output_file']
+        if output_file[-4:] != '.gif':
+            output_file += '.gif'
         if os.path.isfile(output_file) and not self._prop['overwrite_output']:
             raise Exception("Output file '%s' already exist. Use" \
                             " 'overwrite_output=True' to overwrite the file." \
@@ -252,7 +281,7 @@ class MovieEncoder(object):
         if size is not None:
             cmd += ' -vf scale=%s:%s' % (size[0], size[1])
         # if no output file is given, use 'movie.avi' as default:
-        if self._prop['output_file'] is None: 
+        if self._prop['output_file'] is None:
             self._prop['output_file'] = 'movie.avi'
         output_file = self._prop['output_file']
         if os.path.isfile(output_file) and not self._prop['overwrite_output']:
@@ -320,7 +349,7 @@ class MovieEncoder(object):
             cmd += ' -g %d' % int(self._prop['gop_size'])
         #cmd += ' -target dvd'
         # if no output file is given, use 'movie.avi' as default:
-        if self._prop['output_file'] is None: 
+        if self._prop['output_file'] is None:
             self._prop['output_file'] = 'movie.avi'
         cmd += ' ' + self._prop['output_file']
         if self._prop['quiet']:
@@ -451,7 +480,7 @@ FRAME_RATE       %(fps)d
 ASPECT_RATIO     %(aspect)s
 FORCE_ENCODE_LAST_FRAME
 """ % vars())
-        
+
         # set video bit rate and buffer size:
         vbitrate = self._prop['vbitrate']
         if isinstance(vbitrate, (float,int)):
@@ -460,7 +489,7 @@ FORCE_ENCODE_LAST_FRAME
         if isinstance(vbuffer, (float,int)):
             f.write("BUFFER_SIZE      %d" % (int(vbuffer)*1000))
         f.close()
-        
+
         if not hasattr(self, '_tmp_files'):
             self._tmp_files = []
         self._tmp_files.append(mpeg_encode_file)
@@ -483,7 +512,7 @@ FORCE_ENCODE_LAST_FRAME
         png2yuv = 'png2yuv'
         jpeg2yuv = 'jpeg2yuv'
         yuvscaler = 'yuvscaler'
-        
+
         file_type = self._prop['file_type']
         files = self._prop['input_files']
         if isinstance(files, str):
@@ -508,7 +537,7 @@ FORCE_ENCODE_LAST_FRAME
             self._tmp_files = files[:]
             # create a new string with the right pattern:
             files = basename + '%04d.png'
-            
+
         cmd = ''
         if file_type == 'jpg' and findprograms(jpeg2yuv):
             cmd += jpeg2yuv
@@ -534,7 +563,7 @@ FORCE_ENCODE_LAST_FRAME
             cmd += ' | %(yuvscaler)s -O SIZE_%(width)sx%(height)s' % vars()
 
         # if no output file is given, use 'movie.avi' as default:
-        if self._prop['output_file'] is None: 
+        if self._prop['output_file'] is None:
             self._prop['output_file'] = 'movie.mpeg'
         output_file = self._prop['output_file']
         if os.path.isfile(output_file) and not self._prop['overwrite_output']:
@@ -595,7 +624,7 @@ FORCE_ENCODE_LAST_FRAME
                  size=None, ofile_ext='.pnm'):
         """Convert a list of files to the file format specified in the
         ofile_ext keyword argument. Using either Netpbm tools or convert
-        (from the ImageMagick package). 
+        (from the ImageMagick package).
         """
         netpbm_converters = {'.png': ('pngtopnm', 'pnmtopng'),
                              '.gif': ('giftopnm',  'ppmtogif'),
@@ -614,7 +643,7 @@ FORCE_ENCODE_LAST_FRAME
         pnmscale = 'pnmscale'
         #pnmcrop = 'pnmcrop'
         convert = 'convert'
-        
+
         app = anytopnm
         if findprograms((convert, anytopnm, pnmtoany)):
             if self._prop['preferred_package'].lower() == 'imagemagick':
@@ -623,7 +652,7 @@ FORCE_ENCODE_LAST_FRAME
             app = convert
         elif not findprograms((anytopnm, pnmtoany)):
             raise Exception("Neither %s nor %s was found" % (convert,anytopnm))
-        
+
         quiet = self._prop['quiet']
         new_files = []
         i = 1 # counter
@@ -653,7 +682,7 @@ FORCE_ENCODE_LAST_FRAME
                 if size is not None:
                     options += '-resize %sx%s' % size
                 cmd = "%(app)s %(options)s %(file_)s %(new_file)s" % vars()
-            if not quiet: 
+            if not quiet:
                 print cmd
             failure = os.system(cmd)
             if failure:
@@ -700,7 +729,133 @@ FORCE_ENCODE_LAST_FRAME
                 size = size.split('x') # wxh
         if not (isinstance(size, (tuple,list)) and len(size) == 2):
             size = None
-        return size            
+        return size
+
+def html_movie(plotfiles, interval_ms=300, width=800, height=600,
+               casename='movie'):
+    """
+    Takes a list plotfiles which should be for example of the form:
+        ['frame00.png', 'frame01.png', ... ]
+    where each string should be the name of an image file and they should be
+    in the proper order for viewing as an animation.
+
+    The result is html text strings that incorporate javascript to
+    loop through the plots one after another.  The html text also features
+    buttons for controlling the movie.
+    The parameter iterval_ms is the time interval between loading
+    successive images and is in milliseconds.
+
+    The width and height parameters do not seem to have any effect
+    for reasons not understood.
+
+    The following strings are returned: header, javascript code, form
+    with movie and buttons, and footer. Concatenating these strings
+    and dumping to an html file yields a kind of movie file to be
+    viewed in a browser. The images variable in the javascript code
+    is unique for each movie, because it is annotated by the casename
+    string, so several such javascript sections can be used in the
+    same html file.
+
+    This function is based on code written by R.J. LeVeque, based on
+    a template from Alan McIntyre.
+    """
+    import os
+    if not isinstance(plotfiles, (tuple,list)):
+        raise TypeError('html_movie: plotfiles=%s of wrong type %s' %
+                        (str(plotfiles), type(plotfiles)))
+    # Check that the plot files really exist
+    missing_files = [fname for fname in plotfiles if not os.path.isfile(fname)]
+    if missing_files:
+        raise ValueError('Missing plot files: %s' % str(missing_files)[1:-1])
+
+    ext = os.path.splitext(plotfiles[0])[-1]
+    if ext == '.png' or ext == '.jpg' or ext == '.jpeg' or ext == 'gif':
+        pass
+    else:
+        raise ValueError('Plotfiles (%s, ...) must be PNG files with '\
+                         'extension .png' % plotfiles[0])
+    header = """\
+<html>
+<head>
+</head>
+<body>
+"""
+    no_images = len(plotfiles)
+    jscode = """
+<script language="Javascript">
+<!---
+var num_images_%(casename)s = %(no_images)d;
+var img_width = %(width)d;
+var img_height = %(height)d;
+var interval = %(interval_ms)d;
+var images_%(casename)s = new Array();
+
+function preload_images_%(casename)s()
+{
+   t = document.getElementById("progress");
+""" % vars()
+
+    i = 0
+    for fname in plotfiles:
+        jscode += """
+   t.innerHTML = "Preloading image ";
+   images_%(casename)s[%(i)s] = new Image(img_width, img_height);
+   images_%(casename)s[%(i)s].src = "%(fname)s";
+        """ % vars()
+        i = i+1
+    jscode += """
+   t.innerHTML = "";
+}
+
+function tick_%(casename)s()
+{
+   if (frame_%(casename)s > num_images_%(casename)s - 1)
+       frame_%(casename)s = 0;
+
+   document.movie.src = images_%(casename)s[frame_%(casename)s].src;
+   frame_%(casename)s += 1;
+   tt = setTimeout("tick_%(casename)s()", interval);
+}
+
+function startup_%(casename)s()
+{
+   preload_images_%(casename)s();
+   frame_%(casename)s = 0;
+   setTimeout("tick_%(casename)s()", interval);
+}
+
+function stopit()
+{ clearTimeout(tt); }
+
+function restart_%(casename)s()
+{ tt = setTimeout("tick_%(casename)s()", interval); }
+
+function slower()
+{ interval = interval/0.7; }
+
+function faster()
+{ interval = interval*0.7; }
+
+// --->
+</script>
+""" % vars()
+    plotfile0 = plotfiles[0]
+    form = """
+<form>
+&nbsp;
+<input type="button" value="Start movie" onClick="startup_%(casename)s()">
+<input type="button" value="Pause movie" onClick="stopit()">
+<input type="button" value="Restart movie" onClick="restart_%(casename)s()">
+&nbsp;
+<input type="button" value="Slower" onClick="slower()">
+<input type="button" value="Faster" onClick="faster()">
+</form>
+
+<p><div ID="progress"></div></p>
+<img src="%(plotfile0)s" name="movie" border=2/>
+""" % vars()
+    footer = '\n</body>\n</html>\n'
+    return header, jscode, form, footer
 
 
 def movie(input_files, **kwargs):
@@ -709,9 +864,9 @@ def movie(input_files, **kwargs):
 
     This function makes it very easy to create a movie file from a
     series of image files. Several different encoding tools can be
-    used, such as MEncoder, FFmpeg, mpeg_encode, ppmtompeg (Netpbm),
-    mpeg2enc (MJPEGTools), and convert (ImageMagick), to combine the
-    image files together. The encoding tool will be chosen
+    used, such as an HTML file, MEncoder, FFmpeg, mpeg_encode,
+    ppmtompeg (Netpbm), mpeg2enc (MJPEGTools), and convert (ImageMagick),
+    to combine the image files together. The encoding tool will be chosen
     automatically among these if more than one is installed on the
     machine in question (unless it is specified as a keyword argument
     to the movie function).
@@ -725,10 +880,11 @@ def movie(input_files, **kwargs):
 
         movie('image_*.eps')
 
-    The result is a movie file with a default name such as
-    `movie.avi`, `movie.mpeg`, or `movie.gif` (depending on the
-    encoding tool chosen by the movie function). The file resides in
-    the current working directory.
+    The result is a movie file with a default name such as `movie.html`,
+    `movie.avi`, `movie.mpeg`, or `movie.gif`, depending on the
+    encoding tool chosen by the movie function. The file resides in
+    the current working directory. The movie function checks a list of
+    encoders and chooses the first it finds installed on the computer.
 
     Note: We strongly recommend to always clean up previously generated
     files for the frames in movies::
@@ -748,9 +904,17 @@ def movie(input_files, **kwargs):
     The encoder here is the convert program from the ImageMagick suite
     of image manipulation tools. The resulting movie file will be
     named 'wave2D.gif' and placed in the parent directory.
-    
-    If we instead want to create an MPEG movie by using the MEncoder
-    tool, we can do this with the following command::
+
+    Another convenient encoder is simply to make an HTML file that can
+    play a series of image files::
+
+        movie('image_*.png', encoder='html',
+              output_file='../wave2D.html')
+
+    Just load the output file into a web browser and play the movie.
+
+    If you want to create an MPEG movie by using the MEncoder
+    tool, you can do this with the following command::
 
         movie('image_*.eps', encoder='mencoder',
               output_file='/home/johannr/wave2D.mpeg',
@@ -766,7 +930,7 @@ def movie(input_files, **kwargs):
 
     Suitable movie players are vlc for MPEG and AVI formats, and
     animate for animated GIF files.
-    
+
     Below follows a more detailed description of the various arguments that
     are available in this function.
 
@@ -778,12 +942,12 @@ def movie(input_files, **kwargs):
     glob.glob('image_*.png').
 
     Notes:
-                   
+
         * When using the FFmpeg or the Mpeg2enc tools, the image
           files should be given (if possible) as a string on the
           format '{1}%{2}d{3}', where the name components are as
           follows:
-                     
+
           - {1} filename prefix (e.g. image_)
           - {2} counting placeholder (like in C, printf, e.g. 04)
           - {3} file extension (e.g. .png or .jpg)
@@ -793,12 +957,12 @@ def movie(input_files, **kwargs):
           the correct format, there will automatically be made
           copies of these files which will then be renamed to the
           required filename format.
-                     
+
         * MEncoder, FFmpeg, and Mpeg2enc supports only .jpg and
           .png image files. So, if the input files are on another
           format, there will automatically be made copies which
           in turn will be converted to the correct format.
-    
+
     Optional arguments:
 
     output_file: Sets the name of the output movie. If not set, a default
@@ -816,25 +980,25 @@ def movie(input_files, **kwargs):
     overwrite_output: If True, the file given in the output_file
     argument above will be overwritten without warning (if it already
     exists). The default is True.
-    
+
     encoder: Sets the encoder tool to be used. Currently the following
-    encoders are supported: 'mencoder', 'ffmpeg',
+    encoders are supported: 'html', 'mencoder', 'ffmpeg',
     'mpeg_encode', 'ppmtompeg' (from the Netpbm package),
     'mpeg2enc' (from the MJPEGTools package), and 'convert'
     (from the ImageMagick package).
     Note: 'ppmtompeg' and 'mpeg_encode' is the same tool.
-      
+
     vbitrate: Sets the bit rate of the movie. The default is 800 kbps
     when using the FFmpeg and MEncoder encoders. For
     mpeg_encode, ppmtompeg, and mpeg2enc, this option is by
     default not specified. This option has no effect on the
     convert tool from ImageMagick.
 
-    vbuffer: Sets the video buffer size. The default is to use the 
+    vbuffer: Sets the video buffer size. The default is to use the
     current encoding tools default video buffer size. In some
     cases it might be necessary to push this up to 500K or
     more.
-       
+
     fps: Sets the number of frames per second for the final movie.
     The default is 25 fps.
 
@@ -873,14 +1037,14 @@ def movie(input_files, **kwargs):
     'mpeg1video' for mpeg2enc.
 
     Notes:
-                   
+
       * Run 'ffmpeg -formats' for a longer list of available
         codecs.
 
       * The mencoder tool can also use the 'xvid' codec.
 
       * Only 'mpeg1video' and 'mpeg2video' are available when
-        using the mpeg2enc tool. 
+        using the mpeg2enc tool.
 
       * This option has no effect when using mpeg_encode,
         ppmtompeg, or convert as the encoding tool.
@@ -907,10 +1071,10 @@ def movie(input_files, **kwargs):
     The default is to use the same value as in qscale. If
     qscale is not given, then 8 is the default value for
     iqscale.
-                   
+
     pqscale: Same as iqscale, but for P frames. If qscale is not given,
     then 10 is the default value for pqscale.
-    
+
     bqscale: Same as iqscale, but for B frames. If qscale is not given,
     then 25 is the default value for bqscale.
 
@@ -919,7 +1083,7 @@ def movie(input_files, **kwargs):
     worse compression). Another standard sequence is
     'IBBPBBPBBPBBPBB'. This option has only an effect when
     using mpeg_encode or ppmtompeg as the encoding tool.
-       
+
     size: Sets the size of the final movie. The size must be given
     as a tuple/list (e.g. (640,480)) or as a string. The
     format of the string must be 'wxh' (e.g. '320x240'), but
@@ -935,7 +1099,7 @@ def movie(input_files, **kwargs):
     aspect: Sets the aspect ratio of the movie (e.g. 4/3 or 16/9).
 
     Notes:
-                   
+
       * 'mpeg_encode' and 'ppmtompeg' only support the following
         aspect ratios: 1.0, 0.6735, 0.7031, 0.7615,0.8055,
         0.8437, 0.8935, 0.9157, 0.9815, 1.0255, 1.0695, 1.0950,
@@ -960,7 +1124,7 @@ def movie(input_files, **kwargs):
     gop_size: Sets the number of frames in a group of pictures (GOP).
     The default is to use the chosen encoding tools default
     value.
-       
+
     quiet: If True, then the operations will run quietly and only
     complain on errors. The default is False.
 
