@@ -90,7 +90,7 @@ class VtkBackend(BaseClass):
             self._master = Tkinter.Tk()
             self._master.withdraw()
         fig._root = Tkinter.Toplevel(self._master)
-        fig._root.title("EasyViz Data Visualizer - Figure %d" % \
+        fig._root.title("Easyviz VTK Data Visualizer - Figure %d" % \
                         self._attrs['curfig'])
         # if the window is closed, we should delete the current figure and
         # create a new one.
@@ -376,7 +376,7 @@ class VtkBackend(BaseClass):
         tprop.SetVerticalJustificationToTop()
         tprop.SetJustificationToCentered()
 	mapper = vtk.vtkTextMapper()
-        mapper.SetInput(self._axis.getp('title'))
+        mapper.SetInput(self._fix_latex(self._axis.getp('title')))
         mapper.SetTextProperty(tprop)
 	actor = vtk.vtkActor2D()
         actor.SetMapper(mapper)
@@ -1042,8 +1042,20 @@ class VtkBackend(BaseClass):
 
             self._axis._vtk_apd.Update()
 
+    def _fix_latex(self, legend):
+        """Remove latex syntax a la $, \, {, } etc."""
+        legend = legend.strip()
+        # General fix of latex syntax (more readable)
+        legend = legend.replace('**', '^')  
+        #legend = legend.replace('*', '')
+        legend = legend.replace('$', '')
+        legend = legend.replace('{', '')
+        legend = legend.replace('}', '')
+        legend = legend.replace('\\', '')
+        return legend
+
     def _add_legend(self, item, polydata):
-        legend = item.getp('legend')
+        legend = self._fix_latex(item.getp('legend'))
         if legend:
             ax = self._axis
             n = ax._vtk_nolegends
