@@ -7,6 +7,32 @@ import time, sys, os, re, getopt, math, threading, shutil, commands
 from errorcheck import right_type
 from scitools.StringFunction import StringFunction
 
+def import_module(package, module=None):
+    try:
+        if module is not None:
+            stm = 'from %s import %s as m' % (package, module)
+        else:
+            stm = 'import %s as m' % (package)
+        exec(stm)
+        return m
+
+    except ImportError:
+        msg = 'Tried %s,\nbut package %s is not installed' % \
+              (stm, package.split('.')[0])
+        if package.startswith('Scientific'):
+            url = '\nDownload from https://sourcesup.cru.fr/projects/scientific-py/'
+        elif package.startswith('scipy'):
+            url = '\nDownload from http://'
+        elif package.startswith('Pmw'):
+            url = '\nDownload from http://'
+        elif package.startswith('Gnuplot'):
+            url = '\nDownload from http://'
+        else:
+            url = ''
+        msg += url
+        raise ImportError(msg)
+
+
 def test_if_module_exists(modulename, msg='',
                           raise_exception=False, abort=True):
     """
@@ -25,13 +51,13 @@ def test_if_module_exists(modulename, msg='',
         if raise_exception:
             if msg:
                 print msg
-                #print 'The problem arose in ', 
+                #print 'The problem arose in ',
                 debug.trace(frameno=-3)
             raise ImportError(message)
         else:
             if msg:
                 print '\n', message
-                #print 'The problem arose in ', 
+                #print 'The problem arose in ',
                 debug.trace(frameno=-3)
             if abort:
                 sys.exit(1)
@@ -39,7 +65,7 @@ def test_if_module_exists(modulename, msg='',
                 return False
     except Exception, e:
         if msg:
-            print message
+            print msg
             print 'Got an exception while trying to import %s:\n' % \
                 modulename, e
 
@@ -52,8 +78,8 @@ def func_to_method(func, class_, method_name=None):
     Borrowed from recipe 5.12 in the Python Cookbook.
     """
     setattr(class_, method_name or func.__name__, func)
-    
-    
+
+
 def system(command, verbose=True, failure_handling='exit', fake=False):
     """
     User-friendly wrapping of the os.system/os.popen commands.
@@ -65,11 +91,11 @@ def system(command, verbose=True, failure_handling='exit', fake=False):
     command           operating system command to be executed
     verbose           False: no output, True: print command prior to execution
     failure_handling  one of 'exit', 'warning', 'exception', or 'silent'
-                      (in case of failure, the output from the command is 
+                      (in case of failure, the output from the command is
                       always displayed)
     fake              if True, the command is printed but not run (for testing)
-    return value      the same as commands.getstatusoutput, i.e., a boolean 
-                      failure variable and the output from the command as a 
+    return value      the same as commands.getstatusoutput, i.e., a boolean
+                      failure variable and the output from the command as a
                       string object
     ================  ========================================================
     """
@@ -85,7 +111,7 @@ def system(command, verbose=True, failure_handling='exit', fake=False):
     else:
         # Unix/Linux/Mac:
         failure, output = commands.getstatusoutput(command)
-    
+
     if failure:
         msg = 'Failure when running operating system command'\
               '\n  %s\nOutput:\n%s' % (command, output)
@@ -114,7 +140,7 @@ def read_cml(option, default=None, argv=sys.argv):
     from read_cml is a string).
 
     The call::
-    
+
        str2obj(read_cml(option, default=...))
 
     will return a Python object (with the right type) corresponding to
@@ -143,21 +169,19 @@ def read_cml(option, default=None, argv=sys.argv):
                          'no value after %s option' % option)
 
 
-    
+
 def str2bool(s):
     """
     Turn a string s, holding some boolean value
     ('on', 'off', 'True', 'False', 'yes', 'no' - case insensitive)
     into boolean variable. s can also be a boolean. Example:
-    
+
     >>> str2bool('OFF')
     False
     >>> str2bool('yes')
     True
     """
-    if isinstance(s, (bool, int)):
-        return bool(s)
-    elif isinstance(s, str):
+    if isinstance(s, str):
         true_values = ('on', 'true', 'yes')
         false_values = ('off', 'false', 'no')
         s2 = s.lower()  # make case insensitive comparison
@@ -171,7 +195,7 @@ def str2bool(s):
     else:
         raise TypeError('%s %s cannot be converted to bool' % \
                         (s, type(s)))
-    
+
 
 def str2obj(s, globals_=None, locals_=None, debug=False):
     """
@@ -185,7 +209,7 @@ def str2obj(s, globals_=None, locals_=None, debug=False):
     >>> s = str2obj('(1,8)')
     >>> print s, type(s)
     (1, 8) <type 'tuple'>
-    
+
     Method: eval(s) can normally do the job, but if s is meant to
     be turned into a string object, eval works only if s has explicit
     quotes:
@@ -223,7 +247,7 @@ def str2obj(s, globals_=None, locals_=None, debug=False):
     "ON" -> True <type 'bool'>
     "no" -> False <type 'bool'>
     >>>
-    
+
     If the name of a user defined function, class or instance is
     sent to str2obj, the calling code must also send locals() and
     globals() dictionaries as extra arguments. Otherwise, str2obj
@@ -231,7 +255,7 @@ def str2obj(s, globals_=None, locals_=None, debug=False):
     object (user-defined types are unknown inside str2obj unless
     the calling code's globals and locals are provided).
     Here is an example:
-    
+
     >>> def myf(x):
     ...     return 1+x
     ...
@@ -265,7 +289,7 @@ def str2obj(s, globals_=None, locals_=None, debug=False):
         globals_ = globals()
     if locals_ is None:
         locals_ = locals()
-    
+
     try:
         b = str2bool(s)
         return b
@@ -289,7 +313,7 @@ def str2type(value):
     """
     Return a function that can take a string and convert it to
     a Python object of the same type as value.
-    
+
     This function is useful when turning input from GUIs or the
     command line into Python objects. Given a default value for the
     input (with the right object type), str2type will return the right
@@ -311,7 +335,7 @@ def str2type(value):
     be done by the function returned from str2type.
 
     Examples:
-    
+
     >>> f = str2type((1,4,3))
     >>> f.__name__
     'tuple'
@@ -339,60 +363,143 @@ def str2type(value):
     else:
         # the type of value is probably defined in some unknown module
         return str
-    
 
-def interpret_as_callable_or_StringFunction(s, iv, globals_=None):
+
+def interpret_as_callable_or_StringFunction(
+    s, iv, globals_, **named_parameters):
     """
-    Return a callable object if s is the name of such an
-    object, otherwise turn s to a StringFunction with
-    iv as the name of the independent variable.
-    Used by the read_cml function. The globals_ variable is set
-    equal to the module's globals() by default (None).
+    Return a callable object if ``s`` is the name of such an
+    object, otherwise turn ``s`` to a ``StringFunction`` object with
+    ``iv`` as the name of the independent variable.
+    The ``named_parameters`` dictionary holds parameters in
+    string expressions.
+    Used by the ``read_cml`` function.
+
     """
-    if globals_ is None:
-        globals_ = globals()
-    try:
-        evaled_s = eval(s, globals_)
-        if callable(evaled_s):
-            return evaled_s
+    if isinstance(globals_, dict):
+        # First assume s is a user defined function or instance creation
+        if isinstance(s, str):
+            try:
+                obj = eval(s, globals_)
+                if callable(obj):
+                    return obj
+                else:
+                    s_is_string = True
+            except NameError:
+                s_is_string = True
         else:
-            raise ValueError(
-                'string "%s" could be evaluated, but is not callable' % s)
-    except NameError, e:
-        try:
-            if isinstance(iv, str):  # single indep. variable?
-                iv = [iv]
-            func = StringFunction(s, independent_variables=iv,
-                                  globals=globals_)
-        except Exception, e:
-            raise ValueError(
-                '%s\n"%s" must be a function name, instance creation, \
-                or string formula!' % (e, s))
+            if callable(s):  # user function obj or lambda func obj
+                return s
+
+    elif globals_ is None:
+        # No global names supplied, s cannot be the string of a
+        # user function or instance
+        if callable(s):
+            return s
+        else:
+            s_is_string = True
+    else:
+        raise ValueError('globals_ must dict or None')
+
+    if s_is_string:
+        # Assume that s is a string expression
+        if isinstance(iv, str):  # single indep. variable?
+            iv = [iv]
+        func = StringFunction(s, independent_variables=iv,
+                              globals=globals_, **named_parameters)
         return func
+    else:
+        # Should never come here
+        raise ValueError('s is neither a string expression, nor a callable %s' % type(s))
 
 
-def read_cml_func(option, default_func, iv='t', globals_=None):
+
+def read_cml_func(option, default_func, iv='t', globals_=None,
+                  **named_parameters):
     """
-    Locate --option on the command line (sys.argv) and find
-    the corresponding value (next sys.argv element).
-    This value is supposed to specify a function.
-    If --option is not found, the default_func (a given callable)
-    argument is returned.
+    Locate ``--option`` on the command line (``sys.argv``) and find
+    the corresponding value (next ``sys.argv`` element).
+    This value is supposed to specify a Python function, an
+    instance with a ``__call__`` method, None, or a string that can be
+    turned into a ``scitools.StringFunction.StringFunction``
+    function with ``iv`` as the name of the independent variable(s)
+    (list of strings in case of more than one independent variable).
+    If ``--option`` is not found, the argument ``default_func``,
+    a given callable or string, is returned (if string, ``iv``
+    reflects the name of the independent variable(s) in the
+    string).
 
-    The found value is interpreted as either the name of a callable
-    (function or instance) or a string formula.  In both cases, a
-    callable (user-define function, user-defined instance, or
-    StringFunction object) is returned. For StringFunctions the iv
-    argument specifies the name(s) of the independent variable(s).
-    Parameters to StringFunction objects are not supported.  The
-    globals_ argument are used for eval(callable_name) or when
-    creating the  StringFunction object.
+    The ``globals_`` argument is just passed on to the
+    ``StringFunction`` object if the value of the option for default
+    function is a string. Similary, the ``named_parameters`` dictionary
+    is passed on to the ``StringFunction`` object and assumed to
+    hold parameters in the string expressions (variables different
+    from the independent variable).
 
-    Note that this function always returns a callable object,
-    supposed to be a user-defined function.
+    This function always returns a callable object or None.
+
+    Here is an interactive session showing the use of ``read_cml_func``::
+
+    >>> from scitools.misc import read_cml_func
+    >>> import sys
+    >>> from math import sin, cos, pi
+    >>>
+    >>> # fake command-line arguments by filling in sys.argv:
+    >>> sys.argv[1:] = '--func1 myfunc --func3 sin(x)'.split()
+    >>>
+    >>> def myfunc(x):
+    ...     return 1 + x
+    ...
+    >>>
+    >>> # --func1 has myfunc as value, must pass on globals() or just
+    >>> # myfunc as name to read_cml_func
+    >>> #f = read_cml_func('--func1', '1', globals_=globals())
+    >>> f = read_cml_func('--func1', '1', globals_={'myfunc': myfunc})
+    >>> type(f)
+    <type 'function'>
+    >>> f(10)
+    11
+    >>> # --func3 is given as a string expression "sin(x)" on the command line
+    >>> f = read_cml_func('--func3', '0', iv='x')
+    >>> type(f)
+    <type 'instance'>
+    >>> repr(f)
+    "StringFunction('sin(x)', independent_variables=('x',), )"
+    >>> str(f)
+    'sin(x)'
+    >>> f(pi)
+    1.2246467991473532e-16
+    >>>
+    >>> # --func2 is not given on the command line, use the default
+    >>> # value "A*cos(w*t)", which is a string expression.
+    >>> # Pass on a globals_ dict with cos from numpy such that f works
+    >>> # with array argument for t
+    >>> import numpy
+    >>> f = read_cml_func('--func2', 'A*cos(w*t)', iv='t', A=3, w=pi, globals_={'cos': numpy.cos})
+    >>> # More general case where the string should have all numpy functions:
+    >>> #f = read_cml_func('--func2', 'A*cos(w*t)', iv='t', A=3, w=pi, globals_=dir(numpy))
+    >>> type(f)
+    <type 'instance'>
+    >>> repr(f)
+    "StringFunction('A*cos(w*t)', independent_variables=('t',), A=3, w=3.141592653589793)"
+    >>> str(f)
+    '3*cos(3.14159265359*t)'
+    >>> t = numpy.array([1, 4])
+    >>> f(t)
+    array([-3.,  3.])
+    >>>
+    >>> # No --func4 on the command line (sys.argv), implying that
+    >>> # f becomes a StringFunction with value 0
+    >>> f = read_cml_func('--func4', '0')
+    >>> type(f)
+    <type 'instance'>
+    >>> repr(f)
+    "StringFunction('0', independent_variables=('t',), )"
+    >>> str(f)
+    '0'
+    >>> f(1)
+    0
     """
-    if globals_ is None:
-        globals_ = globals()
     if option in sys.argv:
         i = sys.argv.index(option)
         try:
@@ -401,14 +508,124 @@ def read_cml_func(option, default_func, iv='t', globals_=None):
             raise IndexError(
                 'no value after option %s on the command line' \
                 % option)
-        value = interpret_as_callable_or_StringFunction\
-                (value, iv, globals=globals_)
+        return interpret_as_callable_or_StringFunction(
+            value, iv, globals_=globals_, **named_parameters)
     else:
-        value = default_func
-    return value
+        if default_func is None:
+            return None
+        else:
+            # Assume default_func is string expression or a
+            # callable function listed in the globals_ dict
+            # or just a lambda function
+            return interpret_as_callable_or_StringFunction(
+                default_func, iv, globals_=globals_, **named_parameters)
 
 
-def before(string, character):   
+
+def function_UI(functions, argv, verbose=True):
+    """
+    User interface for calling a collection of functions from the
+    command line by writing the function name and its arguments.
+    functions is a list of possible functions to be called. argv is
+    sys.argv from the calling code.
+    function_UI returns a command to be evaluated (function call)
+    in the calling code.
+
+    This function autogenerates a user interface to a module.
+    Suppose a module has a set of functions::
+
+      test_mymethod1(M, q, a, b)
+      test_method2a(a1, a2, a3=0, doc=None)
+      test_method2b()
+
+    The following code automatically creates a user interface
+    and executes calls to the functions above::
+
+      from scitools.misc import function_UI
+      function_names = [fname for fname in dir() if fname.startswith('test_')]
+      function_UI(function_names, sys.argv)
+
+    On the command line the user can now type::
+
+      programname --help
+
+    and automatically get a help string for each function, consisting
+    of the function name, all its positional arguments and all its
+    keyword arguments.
+
+    Alternatively, writing just the function name::
+
+      programname functionname
+
+    prints a usage string if this function requires arguments, otherwise
+    the function is just called.
+
+    Finally, when arguments are supplied::
+
+      programname functionname arg1 arg2 arg3 ...
+
+    the function is called with the given arguments. Safe and easy use
+    is ensured by always giving keyword arguments::
+
+      programname functionname arg1=value1 arg2=value2 arg3=value3 ...
+
+    """
+    usage, doc = _function_args_doc(functions)
+
+    def all_usage():
+        for fname in sorted(usage):
+            print fname, ' '.join(usage[fname])
+
+    # call: function-name arg1 arg2 ...
+    if len(argv) < 2:
+        all_usage()
+        sys.exit(1)
+
+    function_names = [f.__name__ for f in functions]
+    if len(argv) == 2 and argv[1] in function_names and usage[argv[1]]:
+        fname = argv[1]
+        print 'Usage:', fname, ' '.join(usage[fname])
+        if doc[fname]:
+            print '\nDocstring:\n', doc[fname]
+        sys.exit(1)
+
+    if len(argv) == 2 and argv[1].endswith('help'):
+        all_usage()
+        sys.exit(0)
+
+    cmd = '%s(%s)' % (argv[1], ', '.join(argv[2:]))
+    #if len(argv[2:]) == len(usage[fname]):
+        # Correct no arguments (eh, can leave out keyword args...)
+    if verbose:
+        print 'Calling', cmd
+    return cmd
+
+
+def _function_args_doc(functions):
+    """
+    Create documentation of a list of functions.
+    Return: usage dict (usage[funcname] = list of arguments, incl.
+    default values), doc dict (doc[funcname] = docstring (or None)).
+    Called by function_UI.
+    """
+    import inspect
+    usage = {}
+    doc = {}
+    for f in functions:
+        args = inspect.getargspec(f)
+        if args.defaults is None:
+            # Only positional arguments
+            usage[f] = args.args
+        else:
+            # Keyword arguments too, build complete list
+            usage[f.__name__] = args.args[:-len(args.defaults)] + \
+                     ['%s=%s' % (a, d) for a, d in \
+                      zip(args.args[-len(args.defaults):], args.defaults)]
+        doc[f.__name__] = inspect.getdoc(f)
+    return usage, doc
+
+
+def before(string, character):
     """Return part of string before character."""
     for i in range(len(string)):
         if c == character:
@@ -434,7 +651,7 @@ def remove_multiple_items(somelist):
             helphash[item] = 1
     return new
 
-    
+
 def find(func, rootdir, arg=None):
     """
     Traverse the directory tree rootdir and call func for each file.
@@ -530,7 +747,7 @@ def subst(patterns, replacements, filenames,
         if modified_files[pattern]:
             replacement = replacements[patterns.index(pattern)]
             messages.append('%s replaced by %s in %s' % \
-                                (pattern, replacement, 
+                                (pattern, replacement,
                                  ', '.join(modified_files[pattern])))
 
     return ', '.join(messages) if messages else 'no substitutions'
@@ -633,7 +850,7 @@ def findprograms(programs, searchlibs=[], write_message=False):
     A single program can also be given as first argument. In that
     case, findprograms returns True or False according to whether
     the program is found or not.
-    
+
     Example on usage::
 
       if findprograms('plotmtv'):
@@ -670,7 +887,7 @@ def findprograms(programs, searchlibs=[], write_message=False):
             raise TypeError('platform %s/%s not supported' % \
                             (sys.platform, os.name))
         return False # otherwise
-        
+
     path = os.environ['PATH']  # /usr/bin:/usr/local/bin:/usr/X11/bin
     paths = re.split(os.pathsep, path)
     fullpaths = {}
@@ -707,7 +924,7 @@ def findprograms(programs, searchlibs=[], write_message=False):
                     if program_exists(fullpath):
                         fullpaths[program] = fullpath
                         break
-        
+
     if write_message:
         missing = False
         for program in fullpaths.keys():
@@ -720,7 +937,7 @@ def findprograms(programs, searchlibs=[], write_message=False):
                 missing = True
         if missing:
             return None
-        
+
     return fullpaths
 
 
@@ -790,7 +1007,7 @@ def preprocess_all_files(rootdir, options=''):
     # first check that the user has the preprocess script:
     if not findprograms('preprocess'):
         raise SystemError('The preprocess program could not be found')
-    
+
     def treat_a_dir(fileinfo, d, files):
         warning = """\
 #############################################################################
@@ -820,7 +1037,7 @@ def preprocess_all_files(rootdir, options=''):
                     _lines.insert(0, _warning)
                 _str = '\n'.join(_lines)
                 _f = open(outpath, 'w'); _f.write(_str); _f.close()
-                
+
     info = []
     os.path.walk(rootdir, treat_a_dir, info)
     return info
@@ -858,7 +1075,7 @@ def pow_eff(a,b, powfunc=math.pow):
             else:
                 return powfunc(a, b)
 
-    
+
 def lines2paragraphs(lines):
     """
     Return a list of paragraphs from a list of lines
@@ -877,7 +1094,7 @@ def lines2paragraphs(lines):
                 p.append(''.join(lines[firstline:currentline+1]))
                 #print 'paragraph from line',firstline,'to',currentline
             # new paragraph starts from the next line:
-            firstline = currentline+1  
+            firstline = currentline+1
         currentline += 1
     return p
 
@@ -917,7 +1134,7 @@ def wrap(infile, outfile, linewidth=70):
     fi.close()
     fo.close()
 
-            
+
 def fontscheme1(root):
     """Alternative font scheme for Tkinter-based widgets."""
     default_font  = ('Helvetica', 13, 'normal')
@@ -1064,26 +1281,8 @@ class Download(threading.Thread):
 
 def hardware_info():
     """
-    Note: This function is very simple - NumPy has a much more sophisticated
-    module for extracting hardware and CPU information:
-    numpy.distutils.cpuinfo. Here is an example on its usage::
-
-      import numpy.distutils.cpuinfo, pprint
-      pprint.pprint(numpy.distutils.cpuinfo.cpu.info)
-
-    The present hardware_info function serves more as an illustration of
-    how one can easily obtain the most basic hardware information using
-    tools that comes with Python or are easily available from the system.
-
-    ---------------------------------------------------------------------------
-    
-    Extract hardware information using Python's platform module
-    and (if available) files such as /proc/cpuinfo.
-
-    Return: dictionary with keys "uname", "identifier", "python version",
-    "python build", and "cpuinfo".
-    The "identifier" entry is a string that can be
-    used in filenames (the string returned from platform.platform()).
+    Return a dictionary of various types of hardware info from
+    various modules.
 
     Recommended use::
 
@@ -1092,8 +1291,10 @@ def hardware_info():
 
     """
     result = {}
-    
-    # infofile on Linux machines:
+
+    # read cpuinfo file on Linux machines
+    # (numpy.distutils.cpuinfo already does this)
+    """
     infofile = '/proc/cpuinfo'
     cpuinfo = {}
     if os.path.isfile(infofile):
@@ -1103,6 +1304,9 @@ def hardware_info():
                 name, value = [w.strip() for w in line.split(':')]
             except:
                 continue
+            if name not in ('model', 'processor', 'stepping', 'flags',):
+                cpuinfo[name] = value
+            # Override a few with better names
             if name == 'model name':
                 cpuinfo['CPU type'] = value
             elif name == 'cache size':
@@ -1112,14 +1316,36 @@ def hardware_info():
             elif name == 'vendor_id':
                 cpuinfo['vendor ID'] = value
         f.close()
-    result['cpuinfo'] = cpuinfo
-    
-    # check out platform module:
+    result['file: /proc/cpuinfo'] = cpuinfo
+    """
+    import numpy.distutils.cpuinfo, copy
+    info = copy.deepcopy(numpy.distutils.cpuinfo.cpu.info)
+    # Delete some of the items
+    for name in ('model', 'processor', 'stepping', 'flags',):
+        if name in info:
+            del info[name]
+    result['numpy.distutils.cpuinfo.cpu.info'] = info
+
+    # check out platform module from basic Python:
     import platform
-    result['uname'] = platform.uname()
-    result['python version'] = platform.python_version()
-    result['python build'] = platform.python_build()
-    result['identifier'] = platform.platform()
+    platform_info = {
+        'uname': platform.uname(),
+        'python version': platform.python_version(),
+        'python build': platform.python_build(),
+        'identifier': platform.platform()}
+    result['platform module'] = platform_info
+
+    # Trent Mick's platinfo module
+    try:
+        import platinfo2  # code.google.com/p/platinfo
+        try:
+            pi = platinfo.PlatInfo()
+            result['platinfo2 module'] = pi.as_dict()
+        except:
+            pass
+    except:
+        pass
+
     return result
 
 
@@ -1179,7 +1405,7 @@ def flatten(nested_data):
     """
     it = iter(nested_data)
     for e in it:
-        # note: strings are bad because, when iterated they return 
+        # note: strings are bad because, when iterated they return
         # strings, leading to an infinite loop
         if isiterable(e) and not isinstance(e, basestring):
             # recurse into iterators
@@ -1241,15 +1467,15 @@ def cmldict(argv, cmlargs=None, validity=0):
     while arg_counter < len(argv):
         option = argv[arg_counter]
         if option[0] == '-':  option = option[1:]  # remove 1st hyphen
-        else: 
+        else:
             # not an option, proceed with next sys.argv entry
-            arg_counter += 1; continue  
+            arg_counter += 1; continue
         if option[0] == '-':  option = option[1:]  # remove 2nd hyphen
-        
-        if not validity or option in cmlargs: 
+
+        if not validity or option in cmlargs:
             # next argv entry is the value:
             arg_counter += 1
-            value = argv[arg_counter] 
+            value = argv[arg_counter]
             cmlargs[option] = value
         elif validity:
             raise ValueError("The option %s is not registered" % option)
@@ -1267,7 +1493,7 @@ def _cmldict_demo():
     b = p['b']
     # and so on (should have validity=1 to ensure that the
     # option keys are defined)
-    
+
     # take action:
     for option in p.keys():
         if option == "m":
@@ -1305,7 +1531,7 @@ class DoNothing(object):
 
     Whatever we do, we always get a DoNothing object, with which
     we can do whatever we want to, but nothing will happen.
-    
+
     For example, say a plot function returns a plot object that
     is used widely in a code to create windows with visualizations
     on the screen, and you want to turn off all these visualizations:
@@ -1321,30 +1547,125 @@ class DoNothing(object):
     trying properties but no action (DoNothing object)
     >>> type(q)
     <class 'scitools.misc.DoNothing'>
+
+    One can turn the messages 'trying ... but no action' off by
+    giving the argument silent=True to the constructor:
+
+    >>> plot = DoNothing('Plotting turned off', silent=True)
+    >>> viz = plot(u, wireframe=True, title='My plot')
+    >>> viz.update(T)
+    >>> q = viz.properties()
     """
     def __init__(self, *args, **kwargs):
-        pass
+        self.silent = kwargs.get('silent', False)
+
     def __call__(self, *args, **kwargs):
         return DoNothing()
+
     def __repr__(self):
         return ''
+
     def __str__(self):
         return repr(self)
+
     def __getattribute__(self, name):
-        print 'ignoring action "%s" (DoNothing object)' % name
+        if name != 'silent' and not self.silent:
+            print 'ignoring action "%s" (DoNothing object)' % name
         return DoNothing()
+
     def __iter__(self):
         return self
+
     def next(self):
         raise StopIteration()
-    
+
+
+class Recorder:
+    """
+    This class is a wrapper of a module or instance which will
+    record all actions done with the module/instance.
+
+    >>> from scitools.misc import Recorder
+    >>> from scitools.std import plt, plot, linspace
+    >>> x = linspace(-1,1,10)
+    >>> y1 = x**2
+    >>> y2 = x**3
+    >>> plt._g = Recorder(plt._g)  # make the plot object record itself
+    >>> plot(x, y1, 'r-',
+    ...      x, y2, 'b-',
+    ...      title='A test')
+    [<scitools.easyviz.common.Line object at 0x1749c50>, <scitools.easyviz.common.Line object at 0x1749bd0>]
+    >>> # look at what we have done with the plt._g object
+    >>> plt._g.replay()
+    reset()
+    __call__('unset multiplot',)
+    __call__('set datafile missing "nan"',)
+    __call__('set key right top',)
+    __call__('set title "A test"',)
+    __call__('unset logscale x',)
+    __call__('unset logscale y',)
+    __call__('set autoscale',)
+    __call__('set xrange[*:*]',)
+    __call__('set yrange[*:*]',)
+    __call__('set zrange[*:*]',)
+    __call__('set size noratio',)
+    __call__('set size nosquare',)
+    __call__('set yrange [] noreverse',)
+    __call__('set hidden3d',)
+    __call__('unset colorbox',)
+    __call__('set cbrange [*:*]',)
+    __call__('set palette model RGB defined (0 "blue", 3 "cyan", 4 "green", 5 "yellow", 8 "red", 10 "black")',)
+    __call__('unset view',)
+    __call__('set view map',)
+    __call__('set xtics',)
+    __call__('set ytics',)
+    __call__('set ztics',)
+    __call__('set border 1+2+4+8+16 linetype -1 linewidth .4',)
+    __call__('unset xlabel',)
+    __call__('unset ylabel',)
+    __call__('unset zlabel',)
+    __call__('set border 4095 linetype -1 linewidth .4',)
+    __call__('unset grid',)
+    plot(<Gnuplot.PlotItems._FIFOFileItem instance at 0x174d998>,)
+    replot(<Gnuplot.PlotItems._FIFOFileItem instance at 0x174db90>,)
+
+    """
+    def __init__(self, obj):
+        self.obj = obj
+        self.recorder = []
+
+    def __getattr__(self, name):
+        return _RecordHelper(self.obj, name, self.recorder)
+
+    def replay(self):
+        for name, args, kwargs in self.recorder:
+            s = name + '('
+            if args:
+                s += str(args)[1:-1]
+            if kwargs:
+                s += ', ' + ', '.join(['%s=%s' % (key, kwargs[key]) for key in kwargs])
+            s += ')'
+            print s
+
+class _RecordHelper:
+    def __init__(self, obj, name, recorder):
+        self.obj, self.name, self.recorder = obj, name, recorder
+
+    def __call__(self, *args, **kwargs):
+        self.recorder.append((self.name, args, kwargs))
+        if hasattr(self.obj, self.name):
+            return getattr(self.obj, self.name)(*args, **kwargs)
+        else:
+            raise AttributeError('%s has no attribute %s', (self.obj, name))
+
+
 
 def fix_latex_command_regex(pattern, application='match'):
     """
     Given a pattern for a regular expression match or substitution,
     the function checks for problematic patterns commonly
     encountered when working with LaTeX texts, namely commands
-    starting with a backslash. 
+    starting with a backslash.
 
     For a pattern to be matched or substituted, and extra backslash is
     always needed (either a special regex construction like \w leads
